/*******************************************************************
LTCH_MEDPAR_datawork5.do
*******************************************************************/
clear all
cap log close
set more off
set mem 12000m

cd "/net/storage-01/econ/research/jr139/LTCH/"

log using work/datawork/LTCH_MEDPAR_datawork_v5.txt, text replace

	use data/Provider_of_Service_Files/POS_LTC_DEC13.dta
	sort prov_id
	save data/Provider_of_Service_Files/POS_LTC_DEC13.dta,replace
	clear

foreach yr in 02 04 05 06 07 08 09 10 11 12 13 14 15 {

	/*Importing MEDPAR data*/
	insheet using data/ltch/ltch_csv/MEDPAR_LTCH_LDS_20`yr'.csv,delimiter(",")

	cap tostring(discharge_date),replace

	gen quarter_disch = substr(discharge_date,1,1)

	gen cyear = substr(discharge_date,2,3)

	destring(cyear),replace
	replace cyear = cyear+1900 if cyear>=90
	replace cyear = cyear+2000 if cyear<90
	
	gen fyear = 2000+`yr'
	label var fyear "Fiscal year of discharge"
	label var cyear "Calendar year of discharge"
	rename medpar_provider_number prov_id

	/*Dropping observations with invalid prov_id*/
	cap gen nonum = (real(prov_id)==.)

	cap tab nonum
	cap list prov_id if nonum
	cap drop if nonum
	cap drop nonum
	
	/*reformating prov_id to be a six character string*/
	cap destring(prov_id),replace

	gen newprov_id = string(prov_id,"%06.0f")

	drop prov_id
	rename newprov_id prov_id
	sort prov_id
	
	cap tostring(source_of_admission),replace
	
	/*Counting procedure codes*/
	if `yr'>09 {
	forvalues i = 1/25 {
	gen mpc`i' = missing(procedure_code_`i')
	}
	gen number_procedure_codes = mpc1 + mpc2 + mpc3 + mpc4 + mpc5 + mpc6 ///
			+ mpc7 + mpc8 + mpc9 + mpc10 + mpc11 + mpc12 + mpc13 ///
			+ mpc14 + mpc15 + mpc16 + mpc17 + mpc18 + mpc19 ///
			+ mpc20 + mpc21 + mpc22 + mpc23 + mpc24 + mpc25
	}
	/*Saving merged data*/
	save data/MEDPAR_LTCH_`yr'.dta,replace
	clear
}

use data/MEDPAR_LTCH_04.dta

foreach yr in 02 05 06 07 08 09 10 11 12 13 14 15{
	append using data/MEDPAR_LTCH_`yr'.dta, force
	erase "data/MEDPAR_LTCH_`yr'.dta
} 

compress
save data/MEDPAR_LTCH_ALL.dta,replace

/** Merging in hospital data.  Using calendar year. **/

	
merge m:1 prov_id fyear using data/Provider_of_Service_Files/POS_LTAC_ALL.dta
rename _merge _mergePOS
tab _mergePOS year

drop year

/************************************************
	Creating Variables for analysis
************************************************/
sort fyear


cap drop special_unit_character_code /*droping because it is always empty*/
replace pps_indicator = 1 if pps_indicator == 2 /*Making comparable across years*/

/**************Admission data*************************/
gen admin_emergency = type_of_admission==1
gen admin_urgent    = type_of_admission==2
gen admin_elective   = type_of_admission==3
gen admin_other   = type_of_admission==4 | type_of_admission==9

drop if admission_to_death_interval<0

/***************Discharge Indicators********************/
gen disch_alive = (discharge_status=="A")
gen disch_dead  = (discharge_status=="B")
gen disch_home = (discharge_destination==01)|(discharge_destination==06)|(discharge_destination==08) ///
		|(discharge_destination==50)|(discharge_destination==71)
gen disch_hnh = (discharge_destination==01) | (discharge_destination==06)|(discharge_destination==08) ///
		|(discharge_destination==71)
gen disch_hh = discharge_destination==50
gen disch_hospice = discharge_destination==50 | discharge_destination==51

gen disch_stch = (discharge_destination==02)
gen disch_othhosp = (discharge_destination==05)|(discharge_destination==43)|(discharge_destination==61) ///
		   |(discharge_destination==63)|(discharge_destination==65)|(discharge_destination==66)
gen disch_snf  = (discharge_destination==03)
gen disch_othnf = (discharge_destination==04)|(discharge_destination==51)|(discharge_destination==62) ///
		 |(discharge_destination==64)|(discharge_destination==70)
drop discharge_status


/*Day of Discharge*/
gen days = mod(length_of_stay,7)
gen temp1 = day_of_admission+days
gen day_of_discharge = mod(temp1,7)
replace day_of_discharge = 7 if day_of_discharge==0
drop days temp1

/*************Stay data*************/
gen covered = (covered_days>0)
gen coinsurance = (coinsurance_days>0)

gen ICU = (intensive_care_indicator~=.)
gen coronary = (coronary_care_indicator~=.)
gen transplant = (transplant_indicator>0)

gen diagnosis_codes = number_of_diagnosis_codes
gen surgical_codes  = number_of_surgical_codes


/*********************PATIENT CHARACTERISTICS***********/
/*Sex*/
gen male = (sex==1)
drop sex

/*Race*/
gen white = (race==1)
gen black = (race==2)
gen asian = (race==4)
gen hisp  = (race==5)
gen natam = (race==6)
gen rcoth = (race==0)|(race==3)|(race==.)
drop race

gen agegrp = age

/*******************CHARGES AND PAYMENTS*************************/
/** total_charges and covered_charges and reimbursement_amount **/
gen est_tot_costs = total_charges*prov_ccr
gen est_cov_costs = covered_charges*prov_ccr

/*Indicator for ESRD*/
gen ESRD = (medicare_status_code==11)|(medicare_status_code==21)|(medicare_status_code==31)

/*Indicator for disables*/
gen disable = (medicare_status_code==20)|(medicare_status_code==21)

/*Keeping only residents of 50 US states and DC*/
keep if state<54
drop if state==40 | state==48

gen prov_mschlaffl = (prov_medschl<4)

/********AHA ownership*******************/
gen chain = owner~="IND"
replace chain = 1 if owner==""

gen aha_hwh = colocating~=""

sort fyear prov_id
save data/MEDPAR_POS_ALL.dta,replace	
keep 	fyear cyear quarter prov_id pps_indicator  prov_cbsa										///
	/*DRGs*/ drg_code drg_version_24 drg_version_25 drg_version_26 drg_version_27 						///
	drg_version_28 drg_version_29 drg_version_30 drg_version_31 drg_version_32 drg_version_33 drg_version_34	/// 
	current_drg	///													///
	/*Admission data*/ day_of_admission admin_emergency admin_urgent admin_elective admin_other admission_date		///
	/*Discharge data*/ disch_alive disch_dead disch_home disch_stch disch_snf discharge_destination day_of_discharge	///
			   discharge_date disch_othhosp disch_othnf disch_hnh disch_hh disch_hospice 											///
	/*Stay data*/ covered covered_days coinsurance coinsurance_days ICU coronary transplant diagnosis_codes surgical_codes	/// 	
		length_of_stay 			/// 
	/*Patient Characteristics*/ male white black asian hisp natam rcoth agegrp ESRD disable state ///
				    source_of_admission	type_of_admission			///
	/*facility characteristics*/ prov_subcat prov_cat prov_city facname prov_zip prov_fipstate prov_fipscnty prov_beds owner	///
		prov_medschl prov_mcare prov_cardICU prov_resdnts prov_rns prov_fp prov_nfp prov_nfp prov_govt prov_msa prov_ccr ///
		prov_mschlaffl	aha_hwh			///
		select kindred chain aha_hwh hhi hhi_chain preK preS postK postS acquiredK acquiredS divestedK divestedS alwaysK alwaysS neverK neverS		///
		hsa93 hrr93 ltchs_in_hsa ltchs_in_hrr	///
	/*CBSA characteristics*/ cbsa_stach cbsa_ltch cbsa_rehab cbsa_cahosp cbsa_hosp cbsa_nf cbsa_hha cbsa_corf cbsa_hspc     ///
	cbsa_beds cbsa_hosp_beds cbsa_stach_beds cbsa_ltch_beds cbsa_rehab_beds cbsa_nf_beds cbsa_hhi cbsa_sqmi wage_ind        ///
	cbsa_tot_pop cbsa_old_pop cbsa_tot_pop_male cbsa_old_pop_male cbsa_tot_pop_fem cbsa_old_pop_fem ///
	cbsa_wage_index                       ///
	/*Charges and payments*/ total_charges covered_charges reimbursement_amount est_tot_costs est_cov_costs                 ///
	primary_payer_amount coinsurance_amount inpatient_deductible drg_price	outlier_amount ///
	/*POA Indicators and Diagnosis Codes*/ poa_indicator diagnostic_codes_1 diagnostic_codes_2 diagnostic_codes_3 diagnostic_codes_4 diagnostic_codes_5 diagnostic_codes_6 diagnostic_codes_7 ///
	diagnostic_codes_8 diagnostic_codes_9 surgery_indicator number_of_surgical_codes surgical_codes_1 surgical_codes_2 surgical_codes_3 surgical_codes_4 ///
	surgical_codes_5 surgical_codes_6 poa_diagnosis_code_count poa_diagnosis_indicator_1 poa_diagnosis_indicator_2 poa_diagnosis_indicator_3 poa_diagnosis_indicator_4 ///
	poa_diagnosis_indicator_5 poa_diagnosis_indicator_6 poa_diagnosis_indicator_7 poa_diagnosis_indicator_8 poa_diagnosis_indicator_9 poa_diagnosis_indicator_10 poa_diagnosis_indicator_11 ///
	poa_diagnosis_indicator_12 poa_diagnosis_indicator_13 poa_diagnosis_indicator_14 poa_diagnosis_indicator_15 poa_diagnosis_indicator_16 poa_diagnosis_indicator_17 poa_diagnosis_indicator_18 ///
	poa_diagnosis_indicator_19 poa_diagnosis_indicator_20 poa_diagnosis_indicator_21 poa_diagnosis_indicator_22 poa_diagnosis_indicator_23 poa_diagnosis_indicator_24 poa_diagnosis_indicator_25 poa_diagnosis_e_code_count ///
	poa_diagnosis_e_indicator_1 poa_diagnosis_e_indicator_2 poa_diagnosis_e_indicator_3 poa_diagnosis_e_indicator_4 poa_diagnosis_e_indicator_5 poa_diagnosis_e_indicator_6 poa_diagnosis_e_indicator_7 poa_diagnosis_e_indicator_8 ///
	poa_diagnosis_e_indicator_9 poa_diagnosis_e_indicator_10 poa_diagnosis_e_indicator_11 poa_diagnosis_e_indicator_12 diagnosis_code_count diagnosis_code_version diagnosis_code_1 diagnosis_code_2 diagnosis_code_3 ///
	diagnosis_code_4 diagnosis_code_5 diagnosis_code_6 diagnosis_code_7 diagnosis_code_8 diagnosis_code_9 diagnosis_code_10 diagnosis_code_11 diagnosis_code_12 diagnosis_code_13 diagnosis_code_14 diagnosis_code_15 ///
	diagnosis_code_16 diagnosis_code_17 diagnosis_code_18 diagnosis_code_19 diagnosis_code_20 diagnosis_code_21 diagnosis_code_22 diagnosis_code_23 diagnosis_code_24 diagnosis_code_25 diagnosis_e_code_count ///
	diagnosis_e_code_version diagnosis_e_code_1 diagnosis_e_code_2 diagnosis_e_code_3 diagnosis_e_code_4 diagnosis_e_code_5 diagnosis_e_code_6 diagnosis_e_code_7 diagnosis_e_code_8 diagnosis_e_code_9 ///
	diagnosis_e_code_10 diagnosis_e_code_11 diagnosis_e_code_12 procedure_code_count procedure_code_version procedure_code_1 procedure_code_2 procedure_code_3 procedure_code_4 procedure_code_5 procedure_code_6 ///
	procedure_code_7 procedure_code_8 procedure_code_9 procedure_code_10 procedure_code_11 procedure_code_12 procedure_code_13 procedure_code_14 procedure_code_15 procedure_code_16 procedure_code_17 procedure_code_18 ///
	procedure_code_19 procedure_code_20 procedure_code_21 procedure_code_22 procedure_code_23 procedure_code_24 procedure_code_25 admitting_diagnosis_version admitting_diagnosis_code drg_version_29 drg_version_30 ///
	ip_low_volume_amount diagnosis_version_code_1 diagnosis_version_code_2 diagnosis_version_code_3 diagnosis_version_code_4 diagnosis_version_code_5 diagnosis_version_code_6 diagnosis_version_code_7 diagnosis_version_code_8 ///
	diagnosis_version_code_9 diagnosis_version_code_10 diagnosis_version_code_11 diagnosis_version_code_12 diagnosis_version_code_13 diagnosis_version_code_14 diagnosis_version_code_15 diagnosis_version_code_16 ///
	diagnosis_version_code_17 diagnosis_version_code_18 diagnosis_version_code_19 diagnosis_version_code_20 diagnosis_version_code_21 diagnosis_version_code_22 diagnosis_version_code_23 diagnosis_version_code_24 ///
	diagnosis_version_code_25 diagnosis_e_version_code_1 diagnosis_e_version_code_2 diagnosis_e_version_code_3 diagnosis_e_version_code_4 diagnosis_e_version_code_5 diagnosis_e_version_code_6 diagnosis_e_version_code_7 ///
	diagnosis_e_version_code_8 diagnosis_e_version_code_9 diagnosis_e_version_code_10 diagnosis_e_version_code_11 diagnosis_e_version_code_12 procedure_days procedure_version_code_1 procedure_version_code_2 procedure_version_code_3 ///
	procedure_version_code_4 procedure_version_code_5 procedure_version_code_6 procedure_version_code_7 procedure_version_code_8 procedure_version_code_9 procedure_version_code_10 procedure_version_code_11 procedure_version_code_12  ///
	procedure_version_code_13 procedure_version_code_14 procedure_version_code_15 procedure_version_code_16 procedure_version_code_17 procedure_version_code_18 procedure_version_code_19 procedure_version_code_20 procedure_version_code_21 ///
	procedure_version_code_22 procedure_version_code_23 procedure_version_code_24 procedure_version_code_25 number_of_diagnosis_codes number_procedure_codes
	
save data/MEDPAR_POS_ALL.dta,replace	

clear
use data/MEDPAR_POS_ALL.dta,replace

gen drg = .
replace drg = drg_code if fyear==2002
replace drg = drg_code if fyear==2004
replace drg = drg_code if fyear==2005
replace drg = drg_code if fyear==2006
replace drg = drg_code if fyear==2007
replace drg = drg_version_25 if fyear==2008
replace drg = drg_version_26 if fyear==2009
replace drg = drg_version_27 if fyear==2010
replace drg = drg_version_28 if fyear==2011
replace drg = drg_version_29 if fyear==2012
replace drg = drg_version_30 if fyear==2013
replace drg = drg_version_31 if fyear==2014
replace drg = drg_version_32 if fyear==2015

tostring(drg),replace

/** Creating DRG codes that are comparable across years.  I'll call these "cDRG" **/

gen cDRG = 0

/** DRG 207 **/
replace cDRG = 207 if fyear<=2006 & drg=="475"
replace cDRG = 207 if fyear==2007 & drg=="565"
replace cDRG = 207 if fyear>=2008 & drg=="207"

/** DRG 189 **/
replace cDRG = 189 if fyear<=2007 & drg=="87"
replace cDRG = 189 if fyear>2007  & drg=="189"

/** DRG 871 **/
replace cDRG = 871 if fyear<=2006 & drg=="416"
replace cDRG = 871 if fyear==2007 & drg=="576"
replace cDRG = 871 if fyear>=2008 & drg=="871"

/** DRG 177--This one doesn't work perfectly but this is as good as 
					it gets (cc/MCC split in 2008)**/
replace cDRG = 177 if fyear<=2007 & drg=="79"
replace cDRG = 177 if fyear>=2008 & drg=="177"

/** DRG 592 (CC/MCC split in 2008)**/
replace cDRG = 592 if fyear<=2007 & drg=="271"
replace cDRG = 592 if fyear>=2008 & drg=="592"

/** DRG 949 **/
replace cDRG = 949 if drg=="949"

/** DRG 190 (CC/MCC split in 2008)**/
replace cDRG = 190 if fyear<=2007 & drg=="88"
replace cDRG = 190 if fyear>=2008 & drg=="190"

/** DRG 539 (CC/MCC split in 2008) **/
replace cDRG = 539 if fyear<=2007 & drg=="238"
replace cDRG = 539 if fyear>=2008 & drg=="539"

/** DRG 193 (CC/MCC split in 2008)**/
replace cDRG = 193 if fyear<=2007 & drg=="89"
replace cDRG = 193 if fyear>=2008 & drg=="193"
/***********************************************************/

/**Adding wage indeces **/
replace wage_ind = cbsa_wage_index if wage_ind==.
cap drop _merge
sort prov_id fyear
by prov_id:egen temp_cbsa = max(prov_cbsa)
replace prov_cbsa = temp_cbsa if prov_cbsa==.
drop temp_cbsa
tostring(prov_cbsa),replace

sort prov_cbsa fyear
merge prov_cbsa fyear using data/CBSA/wage_index/wageindexcbsa.dta
replace wage_ind = wi if wage_ind==.
drop _merge wi name
tostring(prov_msa),replace
sort prov_msa fyear
merge prov_msa fyear using data/CBSA/wage_index/wageindexmsa.dta
replace wage_ind = wi if wage_ind==.
drop _merge wi name
destring(prov_msa),replace
destring(prov_cbsa),replace
tab fyear if wage_ind==.

/** Merging in DRG data, using fiscal years. **/
gen year = fyear

sort year drg



save data/MEDPAR_POS_ALL.dta,replace

merge year drg using "data/DRGs/DRG_LTCH_ALL.dta"
tab _merge
keep if _merge==3 | year==2002

drop _merge

sort year drg
/*Generating indicator for 95, 90, 10, 5 percentile outliers*/
by year drg: egen temp = pctile(length_of_stay) if (disch_alive==1)*(disch_home==1),p(95)
replace temp = . if (disch_alive==0)|(disch_home==0)
gen drg_pct_95 = (temp<length_of_stay)
drop temp

by year drg: egen temp = pctile(length_of_stay) if (disch_alive==1)*(disch_home==1),p(90)
replace temp = . if (disch_alive==0)|(disch_home==0)
gen drg_pct_90 = (temp<length_of_stay)
drop temp

by year drg: egen temp = pctile(length_of_stay) if (disch_alive==1)*(disch_home==1),p(10)
replace temp = . if (disch_alive==0)|(disch_home==0)
gen drg_pct_10 = (temp<length_of_stay)
drop temp

by year drg: egen temp = pctile(length_of_stay) if (disch_alive==1)*(disch_home==1),p(5)
replace temp = . if (disch_alive==0)|(disch_home==0)
gen drg_pct_5 = (temp<length_of_stay)
drop temp

/*****Creating dd2m - "discharge day relative to magic day" **************/
gen dd2m = floor( (length_of_stay-sso_thresh+0.00001))

save data/MEDPAR_POS_ALL.dta, replace

/** Generating indicator for discharge within a window **/
by year drg: gen wind1 = (length_of_stay>sso_thresh)*(length_of_stay<sso_thresh+1)
by year drg: gen wind2 = (length_of_stay>sso_thresh)*(length_of_stay<sso_thresh+2)
by year drg: gen wind3 = (length_of_stay>sso_thresh)*(length_of_stay<sso_thresh+3)
by year drg: gen wind4 = (length_of_stay>sso_thresh)*(length_of_stay<sso_thresh+4)
by year drg: gen wind5 = (length_of_stay>sso_thresh)*(length_of_stay<sso_thresh+5)
by year drg: gen wind6 = (length_of_stay>sso_thresh)*(length_of_stay<sso_thresh+6)
by year drg: gen wind7 = (length_of_stay>sso_thresh)*(length_of_stay<sso_thresh+7)



/** Generating indicator that discharge is within one week of threshold (before or after) **/
by year drg: gen week1ba  = (length_of_stay>=floor(sso_thresh)-6) & (length_of_stay<=floor(sso_thresh)+7)

/** Generating indicator that discharge iw within two weeks of threshold (before or after) **/
by year drg: gen week2ba  = (length_of_stay>=floor(sso_thresh)-13) & (length_of_stay<=floor(sso_thresh)+14)

drop year

save data/MEDPAR_POS_ALL.dta,replace


/***********************************HHIs**********************************************/
rename cbsa_hhi cbsa_beds_hhi
/** Using fiscal year **/
gen year = fyear

/*DRG specific HHIs*/
sort year prov_cbsa drg
by   year prov_cbsa drg: egen cbsa_drgadmins = count(length_of_stay>0)
sort year prov_id drg
by   year prov_id   drg: egen prov_drgadmins = count(length_of_stay>0)
gen prov_drgshare = prov_drgadmins/cbsa_drgadmins
gen prov_drgshare2 = prov_drgshare^2
sort year prov_cbsa drg

by year prov_cbsa drg: egen cbsa_drghhi = total(prov_drgshare2)

drop cbsa_drgadmins prov_drgadmins prov_drgshare prov_drgshare2

/*Total admissions HHI*/
sort year prov_cbsa
by year prov_cbsa: egen cbsa_admins = count(length_of_stay>0)
sort year prov_id
by year prov_id: egen prov_admins = count(length_of_stay>0)
gen prov_share = prov_admins/cbsa_admins
gen prov_share2 = prov_share^2
sort year prov_cbsa
by year prov_cbsa: egen cbsa_adminhhi = total(prov_share2)
drop cbsa_admins prov_admins prov_share prov_share2 year

save data/MEDPAR_POS_ALL.dta, replace

/** Merging in Standard Federal Rates **/
gen qtr = substr(discharge_date,1,1)
destring(qtr),replace
sort cyear qtr
merge m:1 cyear qtr using data/standard_federal_rate/standard_federal_rates_data.dta

save data/MEDPAR_POS_ALL.dta,replace




// generate a POA for the 2008-2009 series that replaces the string 10 digit variable poa indicator

//Check the correct diagnostic code 
foreach i in 1 2 3 4 5 6 7 8 9{
	icd9 check diagnostic_codes_`i', generate(dc_wrong_`i')
}
//We have a big problem with diagnostic_codes_5 

foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25{
	icd9 check diagnosis_code_`i', generate(dc_wrong2_`i')
}
//Basically diagnosis_code_`i' has no big issues. 

foreach i in 1 2 3 4 5 6 7 8 9{
replace diagnostic_codes_`i'="" if dc_wrong_`i'==10
}

foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25{
replace diagnosis_code_`i'="" if dc_wrong2_`i'==10
}
//Changes for codea too short or long
foreach i in 1 2 3 4 5 6 7 8 9{
replace diagnostic_codes_`i'="" if dc_wrong_`i'==3 | dc_wrong_`i'==4 | dc_wrong_`i'==6
}

foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25{
replace diagnosis_code_`i'="" if dc_wrong2_`i'==3 | dc_wrong2_`i'==4 | dc_wrong2_`i'==6
}
 
//We have trouble with 2008-2009 data since POA indicator is a string variable with 10 characters that doesn't exactly match

replace poa_indicator="" if poa_indicator=="X"
replace poa_indicator="" if poa_indicator=="Z"
replace poa_indicator="" if poa_indicator=="1"
replace poa_indicator="" if poa_indicator=="0"
replace poa_indicator="" if poa_indicator==" "
replace poa_indicator="" if poa_indicator=="2"
replace poa_indicator="" if poa_indicator=="3"
replace poa_indicator="" if poa_indicator=="4"
replace poa_indicator="" if poa_indicator=="5"
replace poa_indicator="" if poa_indicator=="7"
replace poa_indicator="" if poa_indicator=="8"
replace poa_indicator="" if poa_indicator=="9"
replace poa_indicator="" if poa_indicator=="V"

foreach i in 1 2 3 4 5 6 7 8 9 10{
	gen poa_`i'=substr(poa_indicator,`i',1)
}

foreach i in 1 2 3 4 5 6 7 8 9 10{
replace poa_`i'="1" if poa_`i'==" "
}
foreach i in 1 2 3 4 5 6 7 8 9 10{
replace poa_`i'="1" if inlist(poa_`i',"2","3","4","5","6","7","8","9")
}
foreach i in 1 2 3 4 5 6 7 8 9 10{
replace poa_`i'="1" if inlist(poa_`i',"X","Z","0","V","E","T","`")
}

foreach i in 1 2 3 4 5 6 7 8 9{
	gen ctpoa_`i'=1 
	replace ctpoa_`i'=0 if missing(poa_`i')
}
gen finctpoa= ctpoa_1+ctpoa_2+ctpoa_3+ctpoa_4+ctpoa_5+ctpoa_6+ctpoa_7+ctpoa_8+ctpoa_9
tab finctpoa

//Now we want to know how many observations could match with its diagnosis codes 

foreach i in 1 2 3 4 5 6 7 8 9{
	gen ctdc_`i'=1 
	replace ctdc_`i'=0 if missing(diagnostic_codes_`i')
}

gen finctdc= ctdc_1 + ctdc_2 + ctdc_3 + ctdc_4 + ctdc_5 + ctdc_6 + ctdc_7 + ctdc_8 + ctdc_9
tab finctdc

//Check if There are only Y or N, W, U or missing values or 1s
foreach i in 1 2 3 4 5 6 7 8 9{
tab poa_`i'
}

foreach i in 1 2 3 4 5 6 7 8 9{
di `i'
tab poa_indicator if finctpoa==`i' & finctdc==`i'
}

gen match=1
foreach i in 1 2 3 4 5 6 7 8 9{
replace match=2 if poa_`i'=="Y" & diagnostic_codes_`i'==""
}
foreach i in 1 2 3 4 5 6 7 8 9{
replace match=2 if poa_`i'=="N" & diagnostic_codes_`i'==""
}
foreach i in 1 2 3 4 5 6 7 8 9{
replace match=2 if poa_`i'=="U" & diagnostic_codes_`i'==""
}
foreach i in 1 2 3 4 5 6 7 8 9{
replace match=2 if poa_`i'=="W" & diagnostic_codes_`i'==""
}
// Observations that have a POA with Y or N but don't have a matching DC don't make sense
list poa_indicator if match==2

//Problems have to do with poa_9==Y when the diagnostic code is missing (8 cases) If data changes this must be changed manually
replace poa_9 = "" if match==2
//Also, there is a problem with 100 cases where POA indicator doesn't match the number of diagnosis codes
drop match
gen match=0
foreach i in 1 2 3 4 5 6 7 8{
replace match=`i' if finctpoa==`i'
}
gen match2=0
foreach i in 1 2 3 4 5 6 7 8{
replace match2=`i' if finctpoa==`i' & finctdc==`i'
}

gen dif=match-match2
tab dif
//The dif that are different from 0 don't make sense so we replace poa to missing value
//Notice how there are no negative values, so this is the case that we always have more POA than diagnosis code numbers
foreach i in 1 2 3 4 5 6 7 8 9{
replace poa_`i'="" if dif==1
}
foreach i in 1 2 3 4 5 6 7 8 9{
replace poa_`i'="" if dif==2
}
foreach i in 1 2 3 4 5 6 7 8 9{
replace poa_`i'="" if dif==3 
}
foreach i in 1 2 3 4 5 6 7 8 9{
replace poa_`i'="" if dif==4
}
foreach i in 1 2 3 4 5 6 7 8 9{
replace poa_`i'="" if dif==5
}
foreach i in 1 2 3 4 5 6 7 8 9{
replace poa_`i'="" if dif==6
}
foreach i in 1 2 3 4 5 6 7 8 9{
replace poa_`i'="" if dif==7
}
foreach i in 1 2 3 4 5 6 7 8 9{
replace poa_`i'="" if dif==8
}

drop dc_wrong_1 dc_wrong_2 dc_wrong_3 dc_wrong_4 dc_wrong_5 dc_wrong_6 dc_wrong_7 dc_wrong_8 dc_wrong_9 dc_wrong2_1 dc_wrong2_2 dc_wrong2_3 dc_wrong2_4 dc_wrong2_5 dc_wrong2_6 dc_wrong2_7 dc_wrong2_8 dc_wrong2_9 dc_wrong2_10 dc_wrong2_11 dc_wrong2_12 dc_wrong2_13 dc_wrong2_14 dc_wrong2_15 dc_wrong2_16 dc_wrong2_17 dc_wrong2_18 dc_wrong2_19 dc_wrong2_20 dc_wrong2_21 dc_wrong2_22 dc_wrong2_23 dc_wrong2_24 dc_wrong2_25 ctpoa_1 ctpoa_2 ctpoa_3 ctpoa_4 ctpoa_5 ctpoa_6 ctpoa_7 ctpoa_8 ctpoa_9 finctpoa ctdc_1 ctdc_2 ctdc_3 ctdc_4 ctdc_5 ctdc_6 ctdc_7 ctdc_8 ctdc_9 finctdc match match2 dif diagnosis_e_code_version diagnosis_e_code_1 diagnosis_e_code_2 diagnosis_e_code_3 diagnosis_e_code_4 diagnosis_e_code_5 diagnosis_e_code_6 diagnosis_e_code_7 diagnosis_e_code_8 diagnosis_e_code_9 diagnosis_e_code_10 diagnosis_e_code_11 diagnosis_e_code_12 procedure_version_code_1 procedure_version_code_2 procedure_version_code_3 procedure_version_code_4 procedure_version_code_5 procedure_version_code_6 procedure_version_code_7 procedure_version_code_8 procedure_version_code_9 procedure_version_code_10 procedure_version_code_11 procedure_version_code_12 procedure_version_code_13 procedure_version_code_14 procedure_version_code_15 procedure_version_code_16 procedure_version_code_17 procedure_version_code_18 procedure_version_code_19 procedure_version_code_20 procedure_version_code_21 procedure_version_code_22 procedure_version_code_23 procedure_version_code_24 procedure_version_code_25

//Clean the diagnositc code data to be in the correct ICD9 code

foreach i in 1 2 3 4 5 6 7 8 9{
	icd9 clean diagnostic_codes_`i', dots pad
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25{
	icd9 clean diagnosis_code_`i', dots pad
}
save data/HACs/HAC_ALL.dta, replace 

//About Diagnosing HACs
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25{
gen diag_code_desc_`i'=""
}
foreach i in 1 2 3 4 5 6 7 8 9{
replace diag_code_desc_`i'="FORAS" if diagnostic_codes_`i'==" 998.4 " | diagnostic_codes_`i'==" 998.7 "
}
foreach i in 1 2 3 4 5 6 7 8 9{
replace diag_code_desc_`i'="AE" if diagnostic_codes_`i'==" 999.1 "
}
foreach i in 1 2 3 4 5 6 7 8 9{
replace diag_code_desc_`i'="BI" if diagnostic_codes_`i'==" 999.60" | diagnostic_codes_`i'==" 999.61" | diagnostic_codes_`i'==" 999.62" | diagnostic_codes_`i'==" 999.63" | diagnostic_codes_`i'==" 999.69"
}
foreach i in 1 2 3 4 5 6 7 8 9{
replace diag_code_desc_`i'="Ulcer" if diagnostic_codes_`i'==" 707.23" | diagnostic_codes_`i'==" 707.24"
}
foreach i in 1 2 3 4 5 6 7 8 9{
replace diag_code_desc_`i'="FT" if diagnostic_codes_`i'>=" 800   " & diagnostic_codes_`i'<=" 829   "
}
foreach i in 1 2 3 4 5 6 7 8 9{
replace diag_code_desc_`i'="FT" if diagnostic_codes_`i'>=" 830   " & diagnostic_codes_`i'<=" 839   "
}
foreach i in 1 2 3 4 5 6 7 8 9{
replace diag_code_desc_`i'="FT" if diagnostic_codes_`i'>=" 850   " & diagnostic_codes_`i'<=" 854   "
}
foreach i in 1 2 3 4 5 6 7 8 9{
replace diag_code_desc_`i'="FT" if diagnostic_codes_`i'>=" 925   " & diagnostic_codes_`i'<=" 929   "
}
foreach i in 1 2 3 4 5 6 7 8 9{
replace diag_code_desc_`i'="FT" if diagnostic_codes_`i'>=" 940   " & diagnostic_codes_`i'<=" 949   "
}
foreach i in 1 2 3 4 5 6 7 8 9{
replace diag_code_desc_`i'="FT" if diagnostic_codes_`i'>=" 991   " & diagnostic_codes_`i'<=" 994   "
}
foreach i in 1 2 3 4 5 6 7 8 9{
replace diag_code_desc_`i'="UTI" if diagnostic_codes_`i'==" 996.64" 
}
foreach i in 1 2 3 4 5 6 7 8 9{
replace diag_code_desc_`i'="Vascular" if diagnostic_codes_`i'==" 999.31" | diagnostic_codes_`i'==" 999.32" | diagnostic_codes_`i'==" 999.33" 
}
foreach i in 1 2 3 4 5 6 7 8 9{
replace diag_code_desc_`i'="PoorGly" if diagnostic_codes_`i'>=" 250.10" & diagnostic_codes_`i'<=" 250.13"
}
foreach i in 1 2 3 4 5 6 7 8 9{
replace diag_code_desc_`i'="PoorGly" if diagnostic_codes_`i'>=" 250.20" & diagnostic_codes_`i'<=" 250.23"
}
foreach i in 1 2 3 4 5 6 7 8 9{
replace diag_code_desc_`i'="PoorGly" if diagnostic_codes_`i'==" 251.0 "
}
foreach i in 1 2 3 4 5 6 7 8 9{
replace diag_code_desc_`i'="PoorGly" if diagnostic_codes_`i'>=" 249.10" & diagnostic_codes_`i'<=" 249.11"
}
foreach i in 1 2 3 4 5 6 7 8 9{
replace diag_code_desc_`i'="PoorGly" if diagnostic_codes_`i'>=" 249.20" & diagnostic_codes_`i'<=" 249.21"
}

foreach i in 1 2 3 4 5 6 7 8 9{
replace diag_code_desc_`i'="SSInf1" if diagnostic_codes_`i'==" 519.2 & "
}
foreach i in 1 2 3 4 5 6 7 8 9{
replace diag_code_desc_`i'="SSInf2" if diagnostic_codes_`i'==" 996.67" | diagnostic_codes_`i'==" 998.59" 
}
foreach i in 1 2 3 4 5 6 7 8 9{
replace diag_code_desc_`i'="SSInf3" if diagnostic_codes_`i'==" 539.01" | diagnostic_codes_`i'==" 539.81" | diagnostic_codes_`i'==" 998.59" | diagnostic_codes_`i'==" 278.01"
}
foreach i in 1 2 3 4 5 6 7 8 9{
replace diag_code_desc_`i'="SSInf4" if diagnostic_codes_`i'==" 996.61" | diagnostic_codes_`i'==" 998.59" 
}

foreach i in 1 2 3 4 5 6 7 8 9{
replace diag_code_desc_`i'="Embolism" if diagnostic_codes_`i'==" 415.11" | diagnostic_codes_`i'==" 415.13" | diagnostic_codes_`i'==" 415.19"
}
foreach i in 1 2 3 4 5 6 7 8 9{
replace diag_code_desc_`i'="Embolsim" if diagnostic_codes_`i'>=" 453.40" & diagnostic_codes_`i'<=" 453.42" 
}
foreach i in 1 2 3 4 5 6 7 8 9{
replace diag_code_desc_`i'="Cat" if diagnostic_codes_`i'==" 512.1 "
}

foreach i in 1 2 3 4 5 6 7 8 9{
replace diag_code_desc_`i'="Ulcer" if (fyear>=2002 & fyear<=2007 & diagnostic_codes_`i'>=" 707.00" &  diagnostic_codes_`i'<=" 707.09")
}

foreach i in 1 2 3 4 5 6 7 8 9{
replace diag_code_desc_`i'="Ulcer" if (fyear>=2002 & fyear<=2007 & diagnostic_codes_`i'==" 707.24")
}
foreach i in 1 2 3 4 5 6 7 8 9{
replace diag_code_desc_`i'="Ulcer" if (fyear>=2002 & fyear<=2007 & diagnostic_codes_`i'==" 707.23")
}

foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25{
replace diag_code_desc_`i'="FORAS" if diagnosis_code_`i'==" 998.4 " | diagnosis_code_`i'==" 998.7 "
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25{
replace diag_code_desc_`i'="AE" if diagnosis_code_`i'==" 999.1 "
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25{
replace diag_code_desc_`i'="BI" if diagnosis_code_`i'==" 999.60" | diagnosis_code_`i'==" 999.61" | diagnosis_code_`i'==" 999.62" | diagnosis_code_`i'==" 999.63" | diagnosis_code_`i'==" 999.69"
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25{
replace diag_code_desc_`i'="Ulcer" if diagnosis_code_`i'==" 707.23" | diagnosis_code_`i'==" 707.24"
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25{
replace diag_code_desc_`i'="FT" if diagnosis_code_`i'>=" 800   " & diagnosis_code_`i'<=" 829   "
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25{
replace diag_code_desc_`i'="FT" if diagnosis_code_`i'>=" 830   " & diagnosis_code_`i'<=" 839   "
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25{
replace diag_code_desc_`i'="FT" if diagnosis_code_`i'>=" 850   " & diagnosis_code_`i'<=" 854   "
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25{
replace diag_code_desc_`i'="FT" if diagnosis_code_`i'>=" 925   " & diagnosis_code_`i'<=" 929   "
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25{
replace diag_code_desc_`i'="FT" if diagnosis_code_`i'>=" 940   " & diagnosis_code_`i'<=" 949   "
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25{
replace diag_code_desc_`i'="FT" if diagnosis_code_`i'>=" 991   " & diagnosis_code_`i'<=" 994   "
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25{
replace diag_code_desc_`i'="UTI" if diagnosis_code_`i'==" 996.64" 
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25{
replace diag_code_desc_`i'="Vascular" if diagnosis_code_`i'==" 999.31" | diagnosis_code_`i'==" 999.32" | diagnosis_code_`i'==" 999.33" 
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25{
replace diag_code_desc_`i'="PoorGly" if diagnosis_code_`i'>=" 250.10" & diagnosis_code_`i'<=" 250.13"
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25{
replace diag_code_desc_`i'="PoorGly" if diagnosis_code_`i'>=" 250.20" & diagnosis_code_`i'<=" 250.23"
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25{
replace diag_code_desc_`i'="PoorGly" if diagnosis_code_`i'==" 251.0 "
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25{
replace diag_code_desc_`i'="PoorGly" if diagnosis_code_`i'>=" 249.10" & diagnosis_code_`i'<=" 249.11"
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25{
replace diag_code_desc_`i'="PoorGly" if diagnosis_code_`i'>=" 249.20" & diagnosis_code_`i'<=" 249.21"
}

foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25{
replace diag_code_desc_`i'="SSInf1" if diagnosis_code_`i'==" 519.2 "
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25{
replace diag_code_desc_`i'="SSInf2" if diagnosis_code_`i'==" 996.67" | diagnosis_code_`i'==" 998.59" 
}

foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25{
replace diag_code_desc_`i'="SSInf3" if diagnosis_code_`i'==" 539.01" | diagnosis_code_`i'==" 539.81" | diagnosis_code_`i'==" 998.59" | diagnosis_code_`i'==" 278.01"
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25{
replace diag_code_desc_`i'="SSInf4" if diagnosis_code_`i'==" 996.61" | diagnosis_code_`i'==" 998.59" 
}

foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25{
replace diag_code_desc_`i'="Embolism" if diagnosis_code_`i'==" 415.11" | diagnosis_code_`i'==" 415.13" | diagnosis_code_`i'==" 415.19"
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25{
replace diag_code_desc_`i'="Embolism" if diagnosis_code_`i'>=" 453.40" & diagnosis_code_`i'<=" 453.42" 
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25{
replace diag_code_desc_`i'="Cat" if diagnosis_code_`i'==" 512.1 "
}

save data/HACs/HAC_ALL.dta, replace 
//We generate 4 types of Dummy variables
gen FORAS=0
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace FORAS=1 if diag_code_desc_`i'=="FORAS" 
}
gen FORAS_Y=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace FORAS_Y=1 if diag_code_desc_`i'=="FORAS" & poa_`i'=="Y" 
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace FORAS_Y=1 if diag_code_desc_`i'=="FORAS" & poa_diagnosis_indicator_`i'=="Y" 
}
gen FORAS_N=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace FORAS_N=1 if diag_code_desc_`i'=="FORAS" & poa_`i'=="N" 
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace FORAS_N=1 if diag_code_desc_`i'=="FORAS" & poa_diagnosis_indicator_`i'=="N" 
}
gen FORAS_U=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace FORAS_U=1 if (diag_code_desc_`i'=="FORAS" & poa_`i'=="U")
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace FORAS_U=1 if (diag_code_desc_`i'=="FORAS" & poa_diagnosis_indicator_`i'=="U")
}
gen FORAS_W=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace FORAS_W=1 if (diag_code_desc_`i'=="FORAS" & poa_`i'=="W")
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace FORAS_W=1 if (diag_code_desc_`i'=="FORAS" & poa_diagnosis_indicator_`i'=="W")
}
gen FORAS_M=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace FORAS_M=1 if (diag_code_desc_`i'=="FORAS" & poa_`i'~="Y" & poa_`i'~="N" & poa_`i'~="U" & poa_`i'~="W" & fyear<=2009 )
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace FORAS_M=1 if (diag_code_desc_`i'=="FORAS" & poa_diagnosis_indicator_`i'~="Y" & poa_diagnosis_indicator_`i'~="N" & poa_diagnosis_indicator_`i'~="U" & poa_diagnosis_indicator_`i'~="W" & fyear>=2010 )
}

/*Generating "has POA data"*/
gen has_POA = 0
foreach i in 1 2 3 4 5 6 7 8 9{
replace has_POA = 1 if poa_`i'=="Y" |poa_`i'=="N"|poa_`i'=="W"|poa_`i'=="U"
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace has_POA = 1 if poa_diagnosis_indicator_`i'=="Y" |poa_diagnosis_indicator_`i'=="N"|poa_diagnosis_indicator_`i'=="W"|poa_diagnosis_indicator_`i'=="U"

}


//Air Embolism
gen AE=0
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25{
replace AE=1 if diag_code_desc_`i'=="AE" 
}
gen AE_Y=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace AE_Y=1 if diag_code_desc_`i'=="AE" & poa_`i'=="Y" 
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace AE_Y=1 if diag_code_desc_`i'=="AE" & poa_diagnosis_indicator_`i'=="Y" 
}
gen AE_N=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace AE_N=1 if diag_code_desc_`i'=="AE" & poa_`i'=="N" 
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace AE_N=1 if diag_code_desc_`i'=="AE" & poa_diagnosis_indicator_`i'=="N" 
}
gen AE_U=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace AE_U=1 if (diag_code_desc_`i'=="AE" & poa_`i'=="U")
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace AE_U=1 if (diag_code_desc_`i'=="AE" & poa_diagnosis_indicator_`i'=="U")
}
gen AE_W=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace AE_W=1 if (diag_code_desc_`i'=="AE" & poa_`i'=="W")
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace AE_W=1 if (diag_code_desc_`i'=="AE" & poa_diagnosis_indicator_`i'=="W")
}
gen AE_M=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace AE_M=1 if (diag_code_desc_`i'=="AE" & poa_`i'~="Y" & poa_`i'~="N" & poa_`i'~="U" & poa_`i'~="W" & fyear<=2009)
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace AE_M=1 if (diag_code_desc_`i'=="AE" & poa_diagnosis_indicator_`i'~="Y" & poa_diagnosis_indicator_`i'~="N" & poa_diagnosis_indicator_`i'~="U" & poa_diagnosis_indicator_`i'~="W" & fyear>=2010)
}

//Blood Incompatibility
gen BI=0
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25{
replace BI=1 if diag_code_desc_`i'=="BI" 
}
gen BI_Y=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace BI_Y=1 if diag_code_desc_`i'=="BI" & poa_`i'=="Y" 
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace BI_Y=1 if diag_code_desc_`i'=="BI" & poa_diagnosis_indicator_`i'=="Y" 
}
gen BI_N=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace BI_N=1 if diag_code_desc_`i'=="BI" & poa_`i'=="N" 
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace BI_N=1 if diag_code_desc_`i'=="BI" & poa_diagnosis_indicator_`i'=="N" 
}
gen BI_U=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace BI_U=1 if (diag_code_desc_`i'=="BI" & poa_`i'=="U")
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace BI_U=1 if (diag_code_desc_`i'=="BI" & poa_diagnosis_indicator_`i'=="U")
}
gen BI_W=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace BI_W=1 if (diag_code_desc_`i'=="BI" & poa_`i'=="W")
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace BI_W=1 if (diag_code_desc_`i'=="BI" & poa_diagnosis_indicator_`i'=="W")
}
gen BI_M=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace BI_M=1 if (diag_code_desc_`i'=="BI" & poa_`i'~="Y" & poa_`i'~="N" & poa_`i'~="U" & poa_`i'~="W" & fyear<=2009)
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace BI_M=1 if (diag_code_desc_`i'=="BI" & poa_diagnosis_indicator_`i'~="Y" & poa_diagnosis_indicator_`i'~="N" & poa_diagnosis_indicator_`i'~="U" & poa_diagnosis_indicator_`i'~="W" & fyear>=2010)
}

//Pressure Ulcer Stages III & IV
gen Ulcer=0
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25{
replace Ulcer=1 if diag_code_desc_`i'=="Ulcer" 
}
gen Ulcer_Y=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace Ulcer_Y=1 if diag_code_desc_`i'=="Ulcer" & poa_`i'=="Y" 
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace Ulcer_Y=1 if diag_code_desc_`i'=="Ulcer" & poa_diagnosis_indicator_`i'=="Y" 
}
gen Ulcer_N=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace Ulcer_N=1 if diag_code_desc_`i'=="Ulcer" & poa_`i'=="N" 
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace Ulcer_N=1 if diag_code_desc_`i'=="Ulcer" & poa_diagnosis_indicator_`i'=="N" 
}
gen Ulcer_U=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace Ulcer_U=1 if (diag_code_desc_`i'=="Ulcer" & poa_`i'=="U")
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace Ulcer_U=1 if (diag_code_desc_`i'=="Ulcer" & poa_diagnosis_indicator_`i'=="U")
}
gen Ulcer_W=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace Ulcer_W=1 if (diag_code_desc_`i'=="Ulcer" & poa_`i'=="W")
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace Ulcer_W=1 if (diag_code_desc_`i'=="Ulcer" & poa_diagnosis_indicator_`i'=="W")
}
gen Ulcer_M=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace Ulcer_M=1 if (diag_code_desc_`i'=="Ulcer" & poa_`i'~="Y" & poa_`i'~="N" & poa_`i'~="U" & poa_`i'~="W" & fyear<=2009)
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace Ulcer_M=1 if (diag_code_desc_`i'=="Ulcer" & poa_diagnosis_indicator_`i'~="Y" & poa_diagnosis_indicator_`i'~="N" & poa_diagnosis_indicator_`i'~="U" & poa_diagnosis_indicator_`i'~="W" & fyear>=2010)
}

//Falls and Trauma
gen FT=0
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25{
replace FT=1 if diag_code_desc_`i'=="FT" 
}
gen FT_Y=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace FT_Y=1 if diag_code_desc_`i'=="FT" & poa_`i'=="Y" 
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace FT_Y=1 if diag_code_desc_`i'=="FT" & poa_diagnosis_indicator_`i'=="Y" 
}
gen FT_N=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace FT_N=1 if diag_code_desc_`i'=="FT" & poa_`i'=="N" 
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace FT_N=1 if diag_code_desc_`i'=="FT" & poa_diagnosis_indicator_`i'=="N" 
}
gen FT_U=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace FT_U=1 if (diag_code_desc_`i'=="FT" & poa_`i'=="U")
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace FT_U=1 if (diag_code_desc_`i'=="FT" & poa_diagnosis_indicator_`i'=="U")
}
gen FT_W=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace FT_W=1 if (diag_code_desc_`i'=="FT" & poa_`i'=="W")
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace FT_W=1 if (diag_code_desc_`i'=="FT" & poa_diagnosis_indicator_`i'=="W")
}
gen FT_M=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace FT_M=1 if (diag_code_desc_`i'=="FT" & poa_`i'~="Y" & poa_`i'~="N" & poa_`i'~="U" & poa_`i'~="W" & fyear<=2009)
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace FT_M=1 if (diag_code_desc_`i'=="FT" & poa_diagnosis_indicator_`i'~="Y" & poa_diagnosis_indicator_`i'~="N" & poa_diagnosis_indicator_`i'~="U" & poa_diagnosis_indicator_`i'~="W" & fyear>=2010)
}

//Catheter-Associated Urinary Tract Infection (UTI)
gen UTI=0
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25{
replace UTI=1 if diag_code_desc_`i'=="UTI" 
}
gen UTI_Y=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace UTI_Y=1 if diag_code_desc_`i'=="UTI" & poa_`i'=="Y" 
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace UTI_Y=1 if diag_code_desc_`i'=="UTI" & poa_diagnosis_indicator_`i'=="Y" 
}
gen UTI_N=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace UTI_N=1 if diag_code_desc_`i'=="UTI" & poa_`i'=="N" 
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace UTI_N=1 if diag_code_desc_`i'=="UTI" & poa_diagnosis_indicator_`i'=="N" 
}
gen UTI_U=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace UTI_U=1 if (diag_code_desc_`i'=="UTI" & poa_`i'=="U")
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace UTI_U=1 if (diag_code_desc_`i'=="UTI" & poa_diagnosis_indicator_`i'=="U")
}
gen UTI_W=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace UTI_W=1 if (diag_code_desc_`i'=="UTI" & poa_`i'=="W")
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace UTI_W=1 if (diag_code_desc_`i'=="UTI" & poa_diagnosis_indicator_`i'=="W")
}
gen UTI_M=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace UTI_M=1 if (diag_code_desc_`i'=="UTI" & poa_`i'~="Y" & poa_`i'~="N" & poa_`i'~="U" & poa_`i'~="W" & fyear<=2009)
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace UTI_M=1 if (diag_code_desc_`i'=="UTI" & poa_diagnosis_indicator_`i'~="Y" & poa_diagnosis_indicator_`i'~="N" & poa_diagnosis_indicator_`i'~="U" & poa_diagnosis_indicator_`i'~="W" & fyear>=2010)
}


//Vascular Catheter-Associated Infection
gen Vasc=0
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25{
replace Vasc=1 if diag_code_desc_`i'=="Vascular" 
}
gen Vasc_Y=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace Vasc_Y=1 if diag_code_desc_`i'=="Vascular" & poa_`i'=="Y" 
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace Vasc_Y=1 if diag_code_desc_`i'=="Vascular" & poa_diagnosis_indicator_`i'=="Y" 
}
gen Vasc_N=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace Vasc_N=1 if diag_code_desc_`i'=="Vascular" & poa_`i'=="N" 
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace Vasc_N=1 if diag_code_desc_`i'=="Vascular" & poa_diagnosis_indicator_`i'=="N" 
}
gen Vasc_W=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace Vasc_W=1 if (diag_code_desc_`i'=="Vascular" & poa_`i'=="W")
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace Vasc_W=1 if (diag_code_desc_`i'=="Vascular" & poa_diagnosis_indicator_`i'=="W")
}
gen Vasc_U=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace Vasc_U=1 if (diag_code_desc_`i'=="Vascular" & poa_`i'=="W")
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace Vasc_U=1 if (diag_code_desc_`i'=="Vascular" & poa_diagnosis_indicator_`i'=="W")
}
gen Vasc_M=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace Vasc_M=1 if (diag_code_desc_`i'=="Vascular" & poa_`i'~="Y" & poa_`i'~="N" & poa_`i'~="U" & poa_`i'~="W" & fyear<=2009)
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace Vasc_M=1 if (diag_code_desc_`i'=="Vascular" & poa_diagnosis_indicator_`i'~="Y" & poa_diagnosis_indicator_`i'~="N" & poa_diagnosis_indicator_`i'~="U" & poa_diagnosis_indicator_`i'~="W" & fyear>=2010)
}

gen InfUV=0
replace InfUV=1 if Vasc==1 | UTI==1
gen InfUV_Y=0
replace InfUV_Y=1 if Vasc_Y==1 | UTI_Y==1
gen InfUV_N=0
replace InfUV_N=1 if Vasc_N==1 | UTI_N==1
gen InfUV_U=0
replace InfUV_U=1 if Vasc_U==1 | UTI_U==1
gen InfUV_W=0
replace InfUV_W=1 if Vasc_W==1 | UTI_W==1
gen InfUV_M=0
replace InfUV_M = 1 if Vasc_M==1 | UTI_M==1

//Manifestations of Poor Glycemic Control
gen PoorG=0
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25{
replace PoorG=1 if diag_code_desc_`i'=="PoorGly" 
}
gen PoorG_Y=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace PoorG_Y=1 if diag_code_desc_`i'=="PoorGly" & poa_`i'=="Y" 
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace PoorG_Y=1 if diag_code_desc_`i'=="PoorGly" & poa_diagnosis_indicator_`i'=="Y" 
}
gen PoorG_N=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace PoorG_N=1 if diag_code_desc_`i'=="PoorGly" & poa_`i'=="N" 
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace PoorG_N=1 if diag_code_desc_`i'=="PoorGly" & poa_diagnosis_indicator_`i'=="N" 
}
gen PoorG_W=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace PoorG_W=1 if (diag_code_desc_`i'=="PoorGly" & poa_`i'=="W")
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace PoorG_W=1 if (diag_code_desc_`i'=="PoorGly" & poa_diagnosis_indicator_`i'=="W")
}
gen PoorG_U=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace PoorG_U=1 if (diag_code_desc_`i'=="PoorGly" & poa_`i'=="U")
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace PoorG_U=1 if (diag_code_desc_`i'=="PoorGly" & poa_diagnosis_indicator_`i'=="U")
}
gen PoorG_M=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace PoorG_M=1 if (diag_code_desc_`i'=="PoorGly" & poa_`i'~="Y" & poa_`i'~="N" & poa_`i'~="U" & poa_`i'~="W" & fyear<=2009)
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace PoorG_M=1 if (diag_code_desc_`i'=="PoorGly" & poa_diagnosis_indicator_`i'~="Y" & poa_diagnosis_indicator_`i'~="N" & poa_diagnosis_indicator_`i'~="U" & poa_diagnosis_indicator_`i'~="W" & fyear>=2010)
}

gen SSInf1=0
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25{
replace SSInf1=1 if diag_code_desc_`i'=="SSInf1" 
}
gen SSInf1_Y=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace SSInf1_Y=1 if diag_code_desc_`i'=="SSInf1" & poa_`i'=="Y" 
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace SSInf1_Y=1 if diag_code_desc_`i'=="SSInf1" & poa_diagnosis_indicator_`i'=="Y" 
}
gen SSInf1_N=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace SSInf1_N=1 if diag_code_desc_`i'=="SSInf1" & poa_`i'=="N" 
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace SSInf1_N=1 if diag_code_desc_`i'=="SSInf1" & poa_diagnosis_indicator_`i'=="N" 
}
gen SSInf1_U=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace SSInf1_U=1 if (diag_code_desc_`i'=="SSInf1" & poa_`i'=="U")
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace SSInf1_U=1 if (diag_code_desc_`i'=="SSInf1" & poa_diagnosis_indicator_`i'=="U")
}
gen SSInf1_W=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace SSInf1_W=1 if (diag_code_desc_`i'=="SSInf1" & poa_`i'=="W")
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace SSInf1_W=1 if (diag_code_desc_`i'=="SSInf1" & poa_diagnosis_indicator_`i'=="W")
}
gen SSInf1_M=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace SSInf1_M=1 if (diag_code_desc_`i'=="SSInf1" & poa_`i'~="Y" & poa_`i'~="N" & poa_`i'~="U" & poa_`i'~="W" & fyear<=2009)
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace SSInf1_M=1 if (diag_code_desc_`i'=="SSInf1" & poa_diagnosis_indicator_`i'~="Y" & poa_diagnosis_indicator_`i'~="N" & poa_diagnosis_indicator_`i'~="U" & poa_diagnosis_indicator_`i'~="W" & fyear>=2010)
}

gen SSInf2=0
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25{
replace SSInf2=1 if diag_code_desc_`i'=="SSInf2" 
}
gen SSInf2_Y=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace SSInf2_Y=1 if diag_code_desc_`i'=="SSInf2" & poa_`i'=="Y" 
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace SSInf2_Y=1 if diag_code_desc_`i'=="SSInf2" & poa_diagnosis_indicator_`i'=="Y" 
}
gen SSInf2_N=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace SSInf2_N=1 if diag_code_desc_`i'=="SSInf2" & poa_`i'=="N" 
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace SSInf2_N=1 if diag_code_desc_`i'=="SSInf2" & poa_diagnosis_indicator_`i'=="N" 
}
gen SSInf2_U=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace SSInf2_U=1 if (diag_code_desc_`i'=="SSInf2" & poa_`i'=="U")
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace SSInf2_U=1 if (diag_code_desc_`i'=="SSInf2" & poa_diagnosis_indicator_`i'=="U")
}
gen SSInf2_W=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace SSInf2_W=1 if (diag_code_desc_`i'=="SSInf2" & poa_`i'=="W")
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace SSInf2_W=1 if (diag_code_desc_`i'=="SSInf2" & poa_diagnosis_indicator_`i'=="W")
}
gen SSInf2_M=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace SSInf2_M=1 if (diag_code_desc_`i'=="SSInf2" & poa_`i'~="Y" & poa_`i'~="N" & poa_`i'~="U" & poa_`i'~="W" & fyear<=2009)
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace SSInf2_M=1 if (diag_code_desc_`i'=="SSInf2" & poa_diagnosis_indicator_`i'~="Y" & poa_diagnosis_indicator_`i'~="N" & poa_diagnosis_indicator_`i'~="U" & poa_diagnosis_indicator_`i'~="W" & fyear>=2010)
}

gen SSInf3=0
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25{
replace SSInf3=1 if diag_code_desc_`i'=="SSInf3" 
}
gen SSInf3_Y=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace SSInf3_Y=1 if diag_code_desc_`i'=="SSInf3" & poa_`i'=="Y" 
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace SSInf3_Y=1 if diag_code_desc_`i'=="SSInf3" & poa_diagnosis_indicator_`i'=="Y" 
}
gen SSInf3_N=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace SSInf3_N=1 if diag_code_desc_`i'=="SSInf3" & poa_`i'=="N" 
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace SSInf3_N=1 if diag_code_desc_`i'=="SSInf3" & poa_diagnosis_indicator_`i'=="N" 
}
gen SSInf3_U=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace SSInf3_U=1 if (diag_code_desc_`i'=="SSInf3" & poa_`i'=="U")
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace SSInf3_U=1 if (diag_code_desc_`i'=="SSInf3" & poa_diagnosis_indicator_`i'=="U")
}
gen SSInf3_W=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace SSInf3_W=1 if (diag_code_desc_`i'=="SSInf3" & poa_`i'=="W")
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace SSInf3_W=1 if (diag_code_desc_`i'=="SSInf3" & poa_diagnosis_indicator_`i'=="W")
}
gen SSInf3_M=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace SSInf3_M=1 if (diag_code_desc_`i'=="SSInf3" & poa_`i'~="Y" & poa_`i'~="N" & poa_`i'~="U" & poa_`i'~="W" & fyear<=2009)
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace SSInf3_M=1 if (diag_code_desc_`i'=="SSInf3" & poa_diagnosis_indicator_`i'~="Y" & poa_diagnosis_indicator_`i'~="N" & poa_diagnosis_indicator_`i'~="U" & poa_diagnosis_indicator_`i'~="W" & fyear>=2010)
}

gen SSInf4=0
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25{
replace SSInf4=1 if diag_code_desc_`i'=="SSInf4" 
}
gen SSInf4_Y=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace SSInf4_Y=1 if diag_code_desc_`i'=="SSInf4" & poa_`i'=="Y" 
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace SSInf4_Y=1 if diag_code_desc_`i'=="SSInf4" & poa_diagnosis_indicator_`i'=="Y" 
}
gen SSInf4_N=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace SSInf4_N=1 if diag_code_desc_`i'=="SSInf4" & poa_`i'=="N" 
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace SSInf4_N=1 if diag_code_desc_`i'=="SSInf4" & poa_diagnosis_indicator_`i'=="N" 
}
gen SSInf4_U=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace SSInf4_U=1 if (diag_code_desc_`i'=="SSInf4" & poa_`i'=="U")
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace SSInf4_U=1 if (diag_code_desc_`i'=="SSInf4" & poa_diagnosis_indicator_`i'=="U")
}
gen SSInf4_W=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace SSInf4_W=1 if (diag_code_desc_`i'=="SSInf4" & poa_`i'=="W")
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace SSInf4_W=1 if (diag_code_desc_`i'=="SSInf4" & poa_diagnosis_indicator_`i'=="W")
}
gen SSInf4_M=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace SSInf4_M=1 if (diag_code_desc_`i'=="SSInf4" & poa_`i'~="Y" & poa_`i'~="N" & poa_`i'~="U" & poa_`i'~="W" & fyear<=2009)
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace SSInf4_M=1 if (diag_code_desc_`i'=="SSInf4" & poa_diagnosis_indicator_`i'~="Y" & poa_diagnosis_indicator_`i'~="N" & poa_diagnosis_indicator_`i'~="U" & poa_diagnosis_indicator_`i'~="W" & fyear>=2010)
}

gen SSInf=0
replace SSInf=1 if SSInf1==1 | SSInf2==1 | SSInf3==1 | SSInf4==1
gen SSInf_Y=0
replace SSInf_Y=1 if SSInf1_Y==1 | SSInf2_Y==1 | SSInf3_Y==1 | SSInf4_Y==1
gen SSInf_N=0
replace SSInf_N=1 if SSInf1_N==1 | SSInf2_N==1 | SSInf3_N==1 | SSInf4_N==1
gen SSInf_U=0
replace SSInf_U=1 if SSInf1_U==1 | SSInf2_U==1 | SSInf3_U==1 | SSInf4_U==1
gen SSInf_W=0
replace SSInf_W=1 if SSInf1_W==1 | SSInf2_W==1 | SSInf3_W==1 | SSInf4_W==1
gen SSInf_M=0
replace SSInf_M=1 if SSInf1_M==1 | SSInf2_M==1 | SSInf3_M==1 | SSInf4_M==1

//Deep Vein Thrombosis and Pulmonary Embolism Following Certain Orthopedic Procedures 
gen Emb=0
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25{
replace Emb=1 if diag_code_desc_`i'=="Embolism" 
}
gen Emb_Y=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace Emb_Y=1 if diag_code_desc_`i'=="Embolism" & poa_`i'=="Y" 
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace Emb_Y=1 if diag_code_desc_`i'=="Embolism" & poa_diagnosis_indicator_`i'=="Y" 
}
gen Emb_N=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace Emb_N=1 if diag_code_desc_`i'=="Embolism" & poa_`i'=="N" 
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace Emb_N=1 if diag_code_desc_`i'=="Embolism" & poa_diagnosis_indicator_`i'=="N" 
}
gen Emb_U=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace Emb_U=1 if (diag_code_desc_`i'=="Embolism" & poa_`i'=="U")
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace Emb_U=1 if (diag_code_desc_`i'=="Embolism" & poa_diagnosis_indicator_`i'=="U")
}
gen Emb_W=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace Emb_W=1 if (diag_code_desc_`i'=="Embolism" & poa_`i'=="W")
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace Emb_W=1 if (diag_code_desc_`i'=="Embolism" & poa_diagnosis_indicator_`i'=="W")
}
gen Emb_M=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace Emb_M=1 if (diag_code_desc_`i'=="Embolism" & poa_`i'~="Y" & poa_`i'~="N" & poa_`i'~="U" & poa_`i'~="W" & fyear<=2009)
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace Emb_M=1 if (diag_code_desc_`i'=="Embolism" & poa_diagnosis_indicator_`i'~="Y" & poa_diagnosis_indicator_`i'~="N" & poa_diagnosis_indicator_`i'~="U" & poa_diagnosis_indicator_`i'~="W" & fyear>=2010)
}

//Iatrogenic Pneumothorax with Venous Catheterization
gen Cat=0
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25{
replace Cat=1 if diag_code_desc_`i'=="Cat" 
}
gen Cat_Y=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace Cat_Y=1 if diag_code_desc_`i'=="Cat" & poa_`i'=="Y" 
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace Cat_Y=1 if diag_code_desc_`i'=="Cat" & poa_diagnosis_indicator_`i'=="Y" 
}
gen Cat_N=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace Cat_N=1 if diag_code_desc_`i'=="Cat" & poa_`i'=="N" 
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace Cat_N=1 if diag_code_desc_`i'=="Cat" & poa_diagnosis_indicator_`i'=="N" 
}
gen Cat_U=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace Cat_U=1 if (diag_code_desc_`i'=="Cat" & poa_`i'=="U")
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace Cat_U=1 if (diag_code_desc_`i'=="Cat" & poa_diagnosis_indicator_`i'=="U")
}
gen Cat_W=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace Cat_W=1 if (diag_code_desc_`i'=="Cat" & poa_`i'=="W")
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace Cat_W=1 if (diag_code_desc_`i'=="Cat" & poa_diagnosis_indicator_`i'=="W")
}
gen Cat_M=0
foreach i in 1 2 3 4 5 6 7 8 9{
replace Cat_M=1 if (diag_code_desc_`i'=="Cat" & poa_`i'~="Y" & poa_`i'~="N" & poa_`i'~="U" & poa_`i'~="W" & fyear<=2009)
}
foreach i in 1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24{
replace Cat_M=1 if (diag_code_desc_`i'=="Cat" & poa_diagnosis_indicator_`i'~="Y" & poa_diagnosis_indicator_`i'~="N" & poa_diagnosis_indicator_`i'~="U" & poa_diagnosis_indicator_`i'~="W" & fyear>=2010)
}

drop diag_code_desc_1 diag_code_desc_2 diag_code_desc_3 diag_code_desc_4 diag_code_desc_5 diag_code_desc_6 diag_code_desc_7 diag_code_desc_8 diag_code_desc_9 diag_code_desc_10 diag_code_desc_11 diag_code_desc_12 diag_code_desc_13 diag_code_desc_14 diag_code_desc_15 diag_code_desc_16 diag_code_desc_17 diag_code_desc_18 diag_code_desc_19 diag_code_desc_20 diag_code_desc_21 diag_code_desc_22 diag_code_desc_23 diag_code_desc_24 diag_code_desc_25

gen HAC=0
replace HAC=1 if FORAS==1 | AE==1 | BI==1 | Ulcer==1 | FT==1 | UTI==1 | Vasc==1 | PoorG==1 | SSInf1==1 | SSInf2==1 | SSInf3==1 | SSInf4==1 | Emb==1 | Cat==1

gen HAC_Y=0
replace HAC_Y =1 if FORAS_Y ==1 | AE_Y ==1 | BI_Y ==1 | Ulcer_Y ==1 | FT_Y ==1 | UTI_Y ==1 | Vasc_Y ==1 | PoorG_Y ==1 | SSInf1_Y ==1 | SSInf2_Y ==1 | SSInf3_Y ==1 | SSInf4_Y ==1 | Emb_Y ==1 | Cat_Y ==1

gen HAC_N=0
replace HAC_N =1 if FORAS_N ==1 | AE_N ==1 | BI_N ==1 | Ulcer_N ==1 | FT_N ==1 | UTI_N ==1 | Vasc_N ==1 | PoorG_N ==1 | SSInf1_N ==1 | SSInf2_N ==1 | SSInf3_N ==1 | SSInf4_N ==1 | Emb_N ==1 | Cat_N ==1

gen HAC_U=0
replace HAC_U =1 if FORAS_U ==1 | AE_U ==1 | BI_U ==1 | Ulcer_U ==1 | FT_U ==1 | UTI_U ==1 | Vasc_U ==1 | PoorG_U ==1 | SSInf1_U ==1 | SSInf2_U ==1 | SSInf3_U ==1 | SSInf4_U ==1 | Emb_U ==1 | Cat_U ==1

gen HAC_W=0
replace HAC_W =1 if FORAS_W ==1 | AE_W ==1 | BI_W ==1 | Ulcer_W ==1 | FT_W ==1 | UTI_W ==1 | Vasc_W ==1 | PoorG_W ==1 | SSInf1_W ==1 | SSInf2_W ==1 | SSInf3_W ==1 | SSInf4_W ==1 | Emb_W ==1 | Cat_W ==1

gen HAC_M=0
replace HAC_M =1 if FORAS_M ==1 | AE_M ==1 | BI_M ==1 | Ulcer_M ==1 | FT_M ==1 | UTI_M ==1 | Vasc_M ==1 | PoorG_M ==1 | SSInf1_M ==1 | SSInf2_M ==1 | SSInf3_M ==1 | SSInf4_M ==1 | Emb_M ==1 | Cat_M ==1

save data/MEDPAR_POS_ALL.dta, replace 

log close
