clear all
cap log close
set more off
set mem 12000m

cd /net/storage-01/econ/research/jr139/LTCH/

log using work/datawork/POS_datawork_v5.txt, text replace

foreach yr in 02 03 04 05 06 07 08 09 10 {

clear
if `yr'<06 {
	use data/Provider_of_Service_Files/POS_OTHER_DEC`yr'.dta,clear
	destring(prov0085),replace
	destring(prov0075),replace
/*	destring(prov2905),replace*/
	}
else {
	local dfile = "data/Provider_of_Service_Files/POS_OTHER_DEC" + "`yr'" + ".csv"
	disp "`dfile'"
	insheet using "`dfile'",delimiter(",")
	}

rename prov0085 prov_subcat /*Long Term care = 02*/
rename prov0075 prov_cat    /*Hospital = 01*/

rename prov3225 prov_city 

/*Facility Name*/
rename prov0475 facname

/*Provider number*/
rename prov1680 prov_id

/*Formatting ID so it is a 6 character string (with leading zeros)*/
gen newprov_id = string(real(prov_id),"%06.0f")
drop prov_id
rename newprov_id prov_id

/*Street address*/
rename prov2720 prov_addr

/*ZIP code*/
rename prov2905 prov_zip

/*State FIPS code*/
rename fipstate prov_fipstate
destring(prov_fipstate),replace
drop if prov_fipstate==3|prov_fipstate==7|prov_fipstate==14|prov_fipstate==43|prov_fipstate==52

/*County FIPS code*/
cap destring(fipcnty),replace
gen cnty = string(fipcnty, "%03.0f")
tostring(prov_fipstate),gen(st)
gen prov_fipscnty = st+cnty
drop st cnty

/*Medicare/Medicaid eligible?*/
cap destring(prov0455),replace
gen prov_elig = (prov0455==1)

/*For-profit*/
gen prov_fp  = (prov2885=="04")

/*Not-for-profit*/
gen prov_nfp = (prov2885=="01") | (prov2885=="02") | (prov2885=="03")

/*Government Owned*/
gen prov_govt = (prov2885=="05")|(prov2885=="06")|(prov2885=="07")|(prov2885=="08")


/*beds*/
rename prov0740 prov_beds

/*Licensed full-time equivalent practical or vocational nurses*/
rename prov0955 prov_lpns

/*Medical school affiliation*/
rename prov0645 prov_medschl

/*Physician assistants*/
rename prov1115 prov_pas

/*Registered nurses*/
rename prov1145 prov_rns

/*Residents*/
rename prov1165 prov_resdnts

/*Cardiac ICU*/
rename prov2110 prov_cardICU 

/*LCT provided in hospital*/
rename prov2215 prov_LTCSW
tostring(prov_LTCSW),replace

/*Post-opp recovery rooms*/
rename prov2410 prov_postopp

/*Does ltch participate in medicaid or medicare?*/
rename prov1575 prov_mcarepart



keep prov_id facname prov_addr prov_city prov_zip prov_fipstate prov_fipscnty prov_cat prov_subcat ///
     prov_elig prov_fp prov_nfp prov_govt prov_beds prov_lpns prov_medschl prov_pas prov_rns 	   ///
     prov_resdnts prov_cardICU prov_LTCSW prov_postopp prov_mcarepart 
order prov_id facname prov_addr prov_city prov_zip prov_fipstate prov_fipscnty prov_cat prov_subcat ///
     prov_elig prov_fp prov_nfp prov_govt prov_beds prov_lpns prov_medschl prov_pas prov_rns 	   ///
     prov_resdnts prov_cardICU prov_LTCSW prov_postopp prov_mcarepart 
/**The POS data are supposed to represent the providers in the month of December of the listed month.
	I will assign this to the corresponding fiscal year as that is what the claims are in.  It is 
	not a perfect match but it is the best I can reasonably do.			**/
gen fyear=2000+`yr'


/*Saving datasets*/

sort prov_id
save data/Provider_of_Service_Files/POS_DEC`yr'.dta,replace

keep if prov_cat==1 & prov_subcat==1
sort prov_id
save data/Provider_of_Service_Files/POS_AC_DEC`yr'.dta,replace

/********LTAC Hospitals********/

use data/Provider_of_Service_Files/POS_DEC`yr'.dta,clear

keep if prov_cat==1 & prov_subcat==2
sort prov_id

/*Merging in HWH data*/
sort prov_id
merge 1:1 prov_id using data/Provider_of_Service_Files/hwh_DEC`yr'.dta
drop if prov_id==""
drop _merge

/*Merging in CBSA data*/

gen nonum = (real(prov_fipscnty)==.)
drop if nonum==1
drop nonum

cap destring(prov_fipscnty),replace
replace prov_fipscnty = 12086 if prov_fipscnty==12025

sort prov_fipscnty
merge prov_fipscnty using "data/cnty_msa.dta"
list facname prov_fipscnty prov_state prov_city if _merge==1
tab _merge 
drop _merge

sort prov_cbsa
merge m:1 prov_cbsa using "data/CBSA/cbsa_DEC`yr'.dta"
drop if prov_id==""
drop _merge
cap destring(prov_medschl),replace

save data/Provider_of_Service_Files/POS_LTAC_DEC`yr'.dta,replace

}

foreach yr in 11 12 13 14 15 {

clear

local dfile = "data/Provider_of_Service_Files/POS_OTHER_DEC" + "`yr'" + ".csv"

disp "`dfile'"

insheet using "`dfile'",delimiter(",")

rename prvdr_ctgry_sbtyp_cd prov_subcat
rename prvdr_ctgry_cd       prov_cat

/*Facility Name*/
rename fac_name facname

/*Provider number*/
rename prvdr_num prov_id

/*Formatting ID so it is a 6 character string (with leading zeros)*/
gen newprov_id = string(real(prov_id),"%06.0f")
drop prov_id
rename newprov_id prov_id

/*Street address*/
rename st_adr prov_addr

/*State FIPS code*/
rename fips_state_cd prov_fipstate
cap destring(prov_fipstate),replace
drop if prov_fipstate==3 | prov_fipstate==7|prov_fipstate==14|prov_fipstate==43|prov_fipstate==52

/*ZIP code*/
rename zip_cd prov_zip
tostring(prov_zip),replace

/*City of LTCH*/
rename city_name prov_city  

/*County FIPS code*/
gen cnty = string(fips_cnty_cd, "%03.0f")
tostring(prov_fipstate),gen(st)
gen prov_fipscnty = st+cnty
drop st cnty

/*Medicare/Medicaid eligible?*/
gen prov_elig = (elgblty_sw=="Y")

/*For-profit*/
gen prov_fp  = (gnrl_cntl_type_cd=="04")|(gnrl_cntl_type_cd=="09")

/*Not-for-profit.  NOTE:  can be a combination of gov't and non-profit*/
gen prov_nfp = (gnrl_cntl_type_cd=="01") | (gnrl_cntl_type_cd=="02") | (gnrl_cntl_type_cd=="03")

/*Government Owned*/
gen prov_govt = (gnrl_cntl_type_cd=="05")|(gnrl_cntl_type_cd=="06")|(gnrl_cntl_type_cd=="07")|(gnrl_cntl_type_cd=="08")|(gnrl_cntl_type_cd=="10")

/*beds*/
rename bed_cnt prov_beds

/*Licensed full-time equivalent practical or vocational nurses*/
rename lpn_lvn_cnt prov_lpns

/*Medical school affiliation*/
rename mdcl_schl_afltn_cd prov_medschl

/*Physician assistants*/
rename physn_astnt_cnt prov_pas

/*Registered nurses*/
rename rn_cnt prov_rns

/*Residents*/
rename rsdnt_physn_cnt prov_resdnts

/*Cardiac ICU*/
rename crnry_care_unit_srvc_cd prov_cardICU 

/*LCT provided in hospital*/
rename sb_sw prov_LTCSW

/*Post-opp recovery rooms*/
rename pstoprtv_rcvry_srvc_cd prov_postopp

/*Does ltch participate in medicaid or medicare?*/
rename mdcd_mdcr_prtcptg_prvdr_sw prov_mcarepart


keep prov_id facname prov_addr prov_city prov_zip prov_fipstate prov_fipscnty prov_cat prov_subcat ///
     prov_elig prov_fp prov_nfp prov_govt prov_beds prov_lpns prov_medschl prov_pas prov_rns 	   ///
     prov_resdnts prov_cardICU prov_LTCSW prov_postopp prov_mcarepart 
order prov_id facname prov_addr prov_city prov_zip prov_fipstate prov_fipscnty prov_cat prov_subcat ///
     prov_elig prov_fp prov_nfp prov_govt prov_beds prov_lpns prov_medschl prov_pas prov_rns 	   ///
     prov_resdnts prov_cardICU prov_LTCSW prov_postopp prov_mcarepart 

gen fyear=2000+`yr'


/*Saving datasets*/

sort prov_id
save data/Provider_of_Service_Files/POS_DEC`yr'.dta,replace

keep if prov_cat==1 & prov_subcat==1
sort prov_id
save data/Provider_of_Service_Files/POS_AC_DEC`yr'.dta,replace

use data/Provider_of_Service_Files/POS_DEC`yr'.dta,clear

keep if prov_cat==1 & prov_subcat==2
sort prov_id


/*Merging in HWH data*/
/*
sort prov_id
merge prov_id using data/Provider_of_Service_Files/hwh_DEC`yr'.dta
drop if prov_id==""
tab _merge
drop _merge
*/
/*Merging in CBSA data*/

gen nonum = (real(prov_fipscnty)==.)
drop if nonum==1
drop nonum

cap destring(prov_fipscnty),replace
replace prov_fipscnty = 12086 if prov_fipscnty==12025

sort prov_fipscnty
merge prov_fipscnty using "data/cnty_msa.dta"
list facname prov_fipscnty prov_fipstate prov_city if _merge==1
drop if prov_id==""
tab _merge 
drop _merge

sort prov_cbsa
merge prov_cbsa using "data/CBSA/cbsa_DEC`yr'.dta"

tab _merge
drop if prov_id==""
drop _merge

save data/Provider_of_Service_Files/POS_LTAC_DEC`yr'.dta,replace

}

clear

/** Merging Historic Impact Files **/
foreach yr in 02 04 05 06 07 08 09 10 11 12 13 14 15 {
clear
insheet using data/LTCHPPS_Historical_Impact_Files/LTCHPPS_Impact_File_20`yr'.csv,delimit(",")
cap rename provnum prov_id
cap rename providernumber prov_id
rename ccr prov_ccr
keep prov_id prov_ccr year wage_ind
rename year fyear
gen newstr = string(prov_id,"%06.0f")
drop prov_id
rename newstr prov_id
sort prov_id fyear
save data/LTCHPPS_Historical_Impact_Files/LTCHPPS_Impact_File_20`yr'.dta,replace

}
use data/LTCHPPS_Historical_Impact_Files/LTCHPPS_Impact_File_2002.dta,clear
append using data/LTCHPPS_Historical_Impact_Files/LTCHPPS_Impact_File_2004.dta
append using data/LTCHPPS_Historical_Impact_Files/LTCHPPS_Impact_File_2005.dta
append using data/LTCHPPS_Historical_Impact_Files/LTCHPPS_Impact_File_2006.dta
append using data/LTCHPPS_Historical_Impact_Files/LTCHPPS_Impact_File_2007.dta
append using data/LTCHPPS_Historical_Impact_Files/LTCHPPS_Impact_File_2008.dta
append using data/LTCHPPS_Historical_Impact_Files/LTCHPPS_Impact_File_2009.dta
append using data/LTCHPPS_Historical_Impact_Files/LTCHPPS_Impact_File_2010.dta
append using data/LTCHPPS_Historical_Impact_Files/LTCHPPS_Impact_File_2011.dta
append using data/LTCHPPS_Historical_Impact_Files/LTCHPPS_Impact_File_2012.dta
append using data/LTCHPPS_Historical_Impact_Files/LTCHPPS_Impact_File_2013.dta
append using data/LTCHPPS_Historical_Impact_Files/LTCHPPS_Impact_File_2014.dta
append using data/LTCHPPS_Historical_Impact_Files/LTCHPPS_Impact_File_2015.dta
sort prov_id fyear
save data/LTCHPPS_Historical_Impact_Files/LTCHPPS_Impact_File_ALL.dta,replace
erase data/LTCHPPS_Historical_Impact_Files/LTCHPPS_Impact_File_2004.dta
erase data/LTCHPPS_Historical_Impact_Files/LTCHPPS_Impact_File_2005.dta
erase data/LTCHPPS_Historical_Impact_Files/LTCHPPS_Impact_File_2006.dta
erase data/LTCHPPS_Historical_Impact_Files/LTCHPPS_Impact_File_2007.dta
erase data/LTCHPPS_Historical_Impact_Files/LTCHPPS_Impact_File_2008.dta
erase data/LTCHPPS_Historical_Impact_Files/LTCHPPS_Impact_File_2009.dta
erase data/LTCHPPS_Historical_Impact_Files/LTCHPPS_Impact_File_2010.dta
erase data/LTCHPPS_Historical_Impact_Files/LTCHPPS_Impact_File_2011.dta
erase data/LTCHPPS_Historical_Impact_Files/LTCHPPS_Impact_File_2012.dta
erase data/LTCHPPS_Historical_Impact_Files/LTCHPPS_Impact_File_2013.dta
erase data/LTCHPPS_Historical_Impact_Files/LTCHPPS_Impact_File_2014.dta
erase data/LTCHPPS_Historical_Impact_Files/LTCHPPS_Impact_File_2015.dta
clear

use data/Provider_of_Service_Files/POS_LTAC_DEC02.dta,clear
append using data/Provider_of_Service_Files/POS_LTAC_DEC04.dta, force
append using data/Provider_of_Service_Files/POS_LTAC_DEC05.dta, force
append using data/Provider_of_Service_Files/POS_LTAC_DEC06.dta, force
append using data/Provider_of_Service_Files/POS_LTAC_DEC07.dta, force
append using data/Provider_of_Service_Files/POS_LTAC_DEC08.dta, force
append using data/Provider_of_Service_Files/POS_LTAC_DEC09.dta, force
append using data/Provider_of_Service_Files/POS_LTAC_DEC10.dta, force
append using data/Provider_of_Service_Files/POS_LTAC_DEC11.dta, force
append using data/Provider_of_Service_Files/POS_LTAC_DEC12.dta, force
append using data/Provider_of_Service_Files/POS_LTAC_DEC13.dta, force
append using data/Provider_of_Service_Files/POS_LTAC_DEC14.dta, force
append using data/Provider_of_Service_Files/POS_LTAC_DEC15.dta, force
sort prov_id fyear
/**Merging in claim counts to I can keep only hospitals receiving 
	Medicare payments for LTCH stays**/

merge prov_id fyear using data/claim_counts_all.dta
tab _merge
/**Dropping observations in claim_counts_all.dta that are not in POS_LTAC_ALL
	There are 59 of these observations.  They tend to occur when the 
	hospitals open but before they make it into the POS.  Eventually I 
	should go back and fix this.**/

keep if _merge==3
sort prov_id fyear
 /**Keeping only hospitals with positive MEDPAR LTCH claims**/
keep if claim_cnt>0 | claim_cnt~=.
drop _merge

/** Merging in Historic Impact Data **/
merge 1:1 prov_id fyear using data/LTCHPPS_Historical_Impact_Files/LTCHPPS_Impact_File_ALL.dta
tab _merge
drop _merge
sort prov_id fyear


/** Merging in AHA ownership data **/
sort fyear prov_id
merge 1:1 fyear prov_id using data/AHA/AHA_tomerge2.dta
/**There are observations from AHA that are not in claims and in 
claims that are not in AHA.  Need to work out.**/
tab _merge
drop _merge

replace prov_fp   = 1 if owner=="SELECT" | owner=="KINDRED"
replace prov_nfp  = 0 if owner=="SELECT" | owner=="KINDRED"
replace prov_govt = 0 if owner=="SELECT" | owner=="KINDRED"

save data/Provider_of_Service_Files/POS_LTAC_ALL.dta,replace

/**Merging in HSA and HRR Data**/
clear
foreach yr in 04 05 06 07 08 09 10 11 12 13 14 15 {
    if `yr'<15 {
	use data/ZipHsaHrr/ZipHsaHrr`yr',clear
    }
    if `yr'==15 {
    use data/ZipHsaHrr/ZipHsaHrr`yr'_temp,clear
    }
	cap rename hsanum1 hsanum
	cap rename hsacity1 hsacity
	cap rename hsastate1 hsastate
	cap rename hrrcity1 hrrcity
	cap rename hrrstate1 hrrstate
	cap gen fyear=2000+`yr'
	cap rename zipcode`yr' prov_zip
	cap rename hrrnum hrr93
	cap destring(prov_zip),replace
	gen temp = string(prov_zip,"%05.0f")
	drop prov_zip
	rename temp prov_zip
    if `yr'<15 {
	save data/ZipHsaHrr/ZipHsaHrr`yr'.dta,replace
    }
    if `yr'==15 {
    save data/ZipHsaHrr/ZipHsaHrr`yr'_temp.dta,replace
    }
	
}
use data/ZipHsaHrr/ZipHsaHrr04,clear
append using data/ZipHsaHrr/ZipHsaHrr05,force
append using data/ZipHsaHrr/ZipHsaHrr06,force
append using data/ZipHsaHrr/ZipHsaHrr07,force
append using data/ZipHsaHrr/ZipHsaHrr08,force
append using data/ZipHsaHrr/ZipHsaHrr09,force
append using data/ZipHsaHrr/ZipHsaHrr10,force
append using data/ZipHsaHrr/ZipHsaHrr11,force
append using data/ZipHsaHrr/ZipHsaHrr12,force
append using data/ZipHsaHrr/ZipHsaHrr13,force
append using data/ZipHsaHrr/ZipHsaHrr14,force
append using data/ZipHsaHrr/ZipHsaHrr15_temp,force
rename hsanum hsa93
sort fyear prov_zip
save data/ZipHsaHrr/ZipHsaHrr_All.dta,replace

clear

use data/Provider_of_Service_Files/POS_LTAC_ALL.dta,clear
tostring(prov_zip),replace
sort fyear prov_zip
merge fyear prov_zip using data/ZipHsaHrr/ZipHsaHrr_All.dta
drop if prov_id==""
drop _merge

/**Summing number of LTCHs in HSA and HRRs with Medicare Claims**/
sort hsa93 fyear
gen i = 1
by hsa93 fyear: egen ltchs_in_hsa = total(i) if prov_zip~=""
sort hrr93 fyear
by hrr93 fyear: egen ltchs_in_hrr = total(i) if prov_zip~=""
drop i


/**Calculating HHI by HRR**/
sort hrr93 fyear
by hrr93 fyear: egen tot_claims = total(claim_cnt)
gen s2 = claim_cnt*claim_cnt/(tot_claims*tot_claims)
by hrr93 fyear: egen hhi = total(s2)

sort hrr93 fyear owner
by hrr93 fyear owner: egen chain_claims = total(claim_cnt)
by hrr93 fyear owner: gen first = _n==1
gen s2_chain = chain_claims^2/tot_claims^2
by hrr93 fyear: egen temp = total(s2_chain) if first==1
by hrr93 fyear: egen hhi_chain = max(temp)

drop temp s2 s2_chain


/**Calculating pre and post K and S indicators**/
gen select = owner=="SELECT"
gen kindred = owner=="KINDRED"


sort prov_id fyear
by prov_id: gen hosp_year = _n
by prov_id: egen everK = max(kindred)
by prov_id: egen everS = max(select)
gen neverK = 1-everK
gen neverS = 1-everS

by prov_id: egen alwaysK = min(kindred)
by prov_id: egen alwaysS = min(select)

by prov_id: egen firstyear = min(fyear)
by prov_id: egen lastyear  = max(fyear)
by prov_id: egen t1K = min(fyear) if kindred == 1
by prov_id: egen firstK = min(t1K)
by prov_id: egen t1S = min(fyear) if select  == 1
by prov_id: egen firstS = min(t1S)
by prov_id: egen t2K = max(fyear) if kindred == 1
by prov_id: egen lastK = max(t2K)
by prov_id: egen t2S = max(fyear) if select  == 1
by prov_id: egen lastS = max(t2S)

gen acquiredK = 0
replace acquiredK = 1 if firstyear<firstK & everK==1
gen acquiredS = 0
replace acquiredS = 1 if firstyear<firstS & everS==1
gen divestedK = 0
replace divestedK = 1 if lastyear>lastK & everK==1
gen divestedS = 0
replace divestedS = 1 if lastyear>lastS & everS==1

gen preK =  0
replace preK = 1 if acquiredK*(fyear< firstK)
replace preK = 2 if acquiredK*(fyear>=firstK)*kindred

gen preS = 0
replace preS = 1 if acquiredS*(fyear< firstS)
replace preS = 2 if acquiredS*(fyear>=firstS)*select

gen postK = 0
replace postK = 1 if divestedK*(fyear<lastK)*kindred
replace postK = 2 if divestedK*(fyear>lastK)

gen postS = 0
replace postS = 1 if divestedS*(fyear<lastS)*select
replace postS = 2 if divestedS*(fyear>lastS)

drop firstyear lastyear firstK firstS lastK lastS everK everS

save data/Provider_of_Service_Files/POS_LTAC_ALL.dta,replace

clear



/**Merging in nursing home data**/
/**Disabled because it was making duplicates of pairs (prov_id,fyear).  If 
	I ever need to revisit the nursing home stuff I will come here*/
/*
use data/nursing_homes/kindred_snf_count.dta,clear
sort hsa93
clear
use data/Provider_of_Service_Files/POS_LTAC_ALL.dta,clear
sort hsa93
merge hsa93 using data/nursing_homes/nf_count.dta
drop _merge
rename hsa93 prov_hsa93
rename hrr93 prov_hrr93
rename kindred_cnt kindred_nf_hsacount
rename select_cnt select_nf_hsacount
drop if prov_id==""
save data/Provider_of_Service_Files/POS_LTAC_ALL.dta,replace

*/

log close
