/*****************************************************************
figure1_A2.do

Plots agerage Medicare payments and estimated costs by length of
stay to illustrate how much money is on the table for the LTCH
payment nonlinearities.
******************************************************************/
clear all
set more off
cap log close
set mem 12000m

cd /net/storage-01/econ/research/jr139/LTCH/
log using work/figures/cost_figs_v1.txt, text replace
use data/MEDPAR_POS_ALL.dta
drop if reimbursement_amount==0

sort drg fyear length_of_stay

keep if cDRG~=0

gen profit = drg_price-est_cov_costs


/**Generating fullpayment data**/
/*gen fullpayment = ((sfr)*lrs*wage_ind + sfr*(1-lrs))*weight*/
sum drg_price if length_of_stay>30 & cDRG==207
gen fullpayment = r(mean)

/** Generating per-diem **/
gen perdiem = fullpayment/floor(geo_mean)

gen payoff_c1 = 2*perdiem + perdiem*(length_of_stay-1)
replace payoff_c1 = fullpayment if length_of_stay>=floor(geo_mean)-1

/** Generating cost-plus payment **/
gen payoff_c2 = est_cov_costs*1.05

/**Creating relative to magic day variable**/
gen day2magic = floor( (length_of_stay-sso_thresh+0.00001))

/**Combining surgical code and procedural code counts**/
gen procedure_count = number_of_surgical_codes
replace procedure_count = procedure_code_count if fyear>=2010

preserve
keep if fyear>=2005 & fyear<=2010
*keep if procedure_count<=1
*keep if number_of_surgical_codes<=1
*keep if fyear==2007
/**Collapsing by cDRG and length of stay but not by year**/
collapse (mean) drg_price est_cov_costs profit payoff_c1 payoff_c2 ///
	 (median) med_drg_price=drg_price med_est_cov_costs=est_cov_costs med_profit=profit ///
	 (p25) p25_drg_price=drg_price p25_est_cov_costs=est_cov_costs p25_profit=profit ///
	 (p75) p75_drg_price=drg_price p75_est_cov_costs=est_cov_costs p75_profit=profit,by(cDRG length_of_stay)

sort cDRG length_of_stay

local xrange_rel "xscale(range(0 80)) xlabel(0(20)80) xtick(0(10)80)"
local yrange_rel "yscale(range(0 200000)) ylabel(0(50000)200000) ytick(0(50000)200000)"
local xtitle_rel "Length of Stay (Days)"
local ytitle_rel "Dollars"

/**207**/
graph twoway (rarea p25_drg_price p75_drg_price length_of_stay,fcolor(gs15) color(gs15)) ///
	     (rarea p25_est_cov_costs p75_est_cov_costs length_of_stay,fcolor(gs12) color(gs12)) ///
	     (line drg_price length_of_stay,lcolor(black)) ///
	     (line est_cov_costs length_of_stay,lpattern(dash) lcolor(black)) if length_of_stay<80 ///
	     & cDRG==207,legend(label(1 "Payment IQR") label(2 "Cost IQR") label(3 "Mean Payment") ///
	     label(4 "Mean Cost")) xline(28,lpattern(dash)) ytitle(`ytitle_rel') ///
	     xtitle(`xtitle_rel') `xrange_rel' `yrange_rel'

gr export "output/figures/Figure1.png",replace
tabstat drg_price est_cov_costs if cDRG==207,by(length_of_stay)

restore


/**Collapsing by cDRG and length of stay but not by year**/
collapse (mean) drg_price est_cov_costs profit payoff_c1 payoff_c2 ///
	 (median) med_drg_price=drg_price med_est_cov_costs=est_cov_costs med_profit=profit ///
	 (p25) p25_drg_price=drg_price p25_est_cov_costs=est_cov_costs p25_profit=profit ///
	 (p75) p75_drg_price=drg_price p75_est_cov_costs=est_cov_costs p75_profit=profit,by(cDRG day2magic)

sort cDRG day2magic

local xrange_rel "xscale(range(-30 60)) xlabel(-30(30)60) xtick(-30(10)60)"
local yrange_rel "yscale(range(0 200000)) ylabel(0(50000)200000) ytick(0(50000)200000)"
local xtitle_rel "Day of Discharge Relative to Magic Day"
local ytitle_rel "Dollars"

/**207**/
graph twoway (rarea p25_drg_price p75_drg_price day2magic,fcolor(gs15) color(gs15)) ///
	     (rarea p25_est_cov_costs p75_est_cov_costs day2magic,fcolor(gs12) color(gs12)) ///
	     (line drg_price day2magic,lcolor(black)) ///
	     (line est_cov_costs day2magic,lpattern(dash) lcolor(black)) if day2magic<60 ///
	     & cDRG==207,legend(label(1 "Payment IQR") label(2 "Cost IQR") label(3 "Mean Payment") ///
	     label(4 "Mean Cost")) xline(0,lpattern(dash)) ytitle(`ytitle_rel') ///
	     xtitle(`xtitle_rel') `xrange_rel' `yrange_rel'
gr export "output/figures/cost_profits_DRG207.eps",replace
tabstat drg_price est_cov_costs if cDRG==207 & day2magic>-10 & day2magic<10,by(day2magic)
tabstat med_drg_price med_est_cov_costs if cDRG==207 & day2magic>-10 & day2magic<10,by(day2magic) 

graph twoway (line drg_price day2magic,lcolor(black) lpattern(solid)) ///
	     (line payoff_c1 day2magic,lcolor(black) lpattern(dot)) ///
	     if day2magic<60 ///
	     & cDRG==207, legend(label(1 "Mean PPS payments") label(3 "Mean cost estimates") ///
	     label(2 "Mean per diem payments")) xline(0,lpattern(dash)) ytitle(`ytitle_rel') ///
	     xtitle(`xtitle_rel') `xrange_rel' `yrange_rel'
gr export "output/figures/counterfactual_payoffs1_DRG207.eps",replace


graph twoway (line drg_price day2magic,lcolor(black) lpattern(solid)) ///
	     (line payoff_c2 day2magic,lcolor(black) lpattern(dot)) ///
	     (line est_cov_costs day2magic,lcolor(black) lpattern(dash)) if day2magic<60 ///
	     & cDRG==207, legend(label(1 "Mean PPS payments") label(3 "Mean cost estimates") ///
	     label(2 "Mean cost-plus payments")) xline(0,lpattern(dash)) ytitle(`ytitle_rel') ///
	     xtitle(`xtitle_rel') `xrange_rel' `yrange_rel'
gr export "output/figures/counterfactual_payoffs2_DRG207.eps",replace


/**189**/
graph twoway (rarea p25_drg_price p75_drg_price day2magic,fcolor(gs15) color(gs15)) ///
	     (rarea p25_est_cov_costs p75_est_cov_costs day2magic,fcolor(gs12) color(gs12)) ///
	     (line drg_price day2magic,lcolor(black)) ///
	     (line est_cov_costs day2magic,lpattern(dash) lcolor(black)) if day2magic<60 ///
	     & cDRG==189,legend(label(1 "Payment IQR") label(2 "Cost IQR") label(3 "Mean Payment") ///
	     label(4 "Mean Cost")) xline(0,lpattern(dash)) ytitle(`ytitle_rel') ///
	     xtitle(`xtitle_rel') `xrange_rel' `yrange_rel'
gr export "output/figures/cost_profits_DRG189.eps",replace
tabstat drg_price est_cov_costs if cDRG==189 & day2magic>-10 & day2magic<10,by(day2magic)
tabstat med_drg_price med_est_cov_costs if cDRG==189 & day2magic>-10 & day2magic<10,by(day2magic) 

/**871**/
graph twoway (rarea p25_drg_price p75_drg_price day2magic,fcolor(gs15) color(gs15)) ///
	     (rarea p25_est_cov_costs p75_est_cov_costs day2magic,fcolor(gs12) color(gs12)) ///
	     (line drg_price day2magic,lcolor(black)) ///
	     (line est_cov_costs day2magic,lpattern(dash) lcolor(black)) if day2magic<60 ///
	     & cDRG==871,legend(label(1 "Payment IQR") label(2 "Cost IQR") label(3 "Mean Payment") ///
	     label(4 "Mean Cost")) xline(0,lpattern(dash)) ytitle(`ytitle_rel') ///
	     xtitle(`xtitle_rel') `xrange_rel' `yrange_rel'
gr export "output/figures/cost_profits_DRG871.eps",replace
tabstat drg_price est_cov_costs if cDRG==871 & day2magic>-10 & day2magic<10,by(day2magic)
tabstat med_drg_price med_est_cov_costs if cDRG==871 & day2magic>-10 & day2magic<10,by(day2magic) 


/**177**/
graph twoway (rarea p25_drg_price p75_drg_price day2magic,fcolor(gs15) color(gs15)) ///
	     (rarea p25_est_cov_costs p75_est_cov_costs day2magic,fcolor(gs12) color(gs12)) ///
	     (line drg_price day2magic,lcolor(black)) ///
	     (line est_cov_costs day2magic,lpattern(dash) lcolor(black)) if day2magic<60 ///
	     & cDRG==177,legend(label(1 "Payment IQR") label(2 "Cost IQR") label(3 "Mean Payment") ///
	     label(4 "Mean Cost")) xline(0,lpattern(dash)) ytitle(`ytitle_rel') ///
	     xtitle(`xtitle_rel') `xrange_rel' `yrange_rel'
gr export "output/figures/cost_profits_DRG177.eps",replace
tabstat drg_price est_cov_costs if cDRG==177 & day2magic>-10 & day2magic<10,by(day2magic)
tabstat med_drg_price med_est_cov_costs if cDRG==177 & day2magic>-10 & day2magic<10,by(day2magic) 

restore
preserve
keep if fyear==2010
collapse (mean) drg_price est_cov_costs profit ///
	 (median) med_drg_price=drg_price med_est_cov_costs=est_cov_costs med_profit=profit ///
	 (p25) p25_drg_price=drg_price p25_est_cov_costs=est_cov_costs p25_profit=profit ///
	 (p75) p75_drg_price=drg_price p75_est_cov_costs=est_cov_costs p75_profit=profit,by(cDRG length_of_stay)

sort cDRG length_of_stay

local xrange_rel "xscale(range(0 80)) xlabel(0(20)80) xtick(0(10)80)"
local yrange_rel "yscale(range(0 200000)) ylabel(0(50000)200000) ytick(0(50000)200000)"
local xtitle_rel "Length of Stay (Days)"
local ytitle_rel "Dollars"

/**207**/
graph twoway (rarea p25_drg_price p75_drg_price length_of_stay,fcolor(gs15) color(gs15)) ///
	     (rarea p25_est_cov_costs p75_est_cov_costs length_of_stay,fcolor(gs12) color(gs12)) ///
	     (line drg_price length_of_stay,lcolor(black)) ///
	     (line est_cov_costs length_of_stay,lpattern(dash) lcolor(black)) if length_of_stay<80 ///
	     & cDRG==207,legend( label(3 "Mean Payment") label(4 "Mean Cost") label(1 "Payment IQR") ///
	     label(2 "Cost IQR") ) xline(29,lpattern(dash)) ytitle(`ytitle_rel') ///
	     xtitle(`xtitle_rel') `xrange_rel' `yrange_rel'
gr export "output/figures/cost_profits_LOS_DRG207_2010.eps",replace
tabstat drg_price est_cov_costs if cDRG==207 & length_of_stay>24 & length_of_stay<45, ///
	by(length_of_stay)
tabstat med_drg_price med_est_cov_costs if cDRG==207 &  length_of_stay>24 & length_of_stay<45 ///
	,by(length_of_stay) 


/**189**/
graph twoway (rarea p25_drg_price p75_drg_price length_of_stay,fcolor(gs15) color(gs15)) ///
	     (rarea p25_est_cov_costs p75_est_cov_costs length_of_stay,fcolor(gs12) color(gs12)) ///
	     (line drg_price length_of_stay,lcolor(black)) ///
	     (line est_cov_costs length_of_stay,lpattern(dash) lcolor(black)) if length_of_stay<80 ///
	     & cDRG==189,legend(label(1 "Payment IQR") label(2 "Cost IQR") label(3 "Mean Payment") ///
	     label(4 "Mean Cost")) xline(19,lpattern(dash)) ytitle(`ytitle_rel') ///
	     xtitle(`xtitle_rel') `xrange_rel' `yrange_rel'
gr export "output/figures/cost_profits_LOS_DRG189.eps",replace
tabstat drg_price est_cov_costs if cDRG==189 &  length_of_stay>15 & length_of_stay<45, ///
	by(length_of_stay)
tabstat med_drg_price med_est_cov_costs if cDRG==189 &  length_of_stay>15 & length_of_stay<45 ///
	,by(length_of_stay) 

/**871**/
graph twoway (rarea p25_drg_price p75_drg_price length_of_stay,fcolor(gs15) color(gs15)) ///
	     (rarea p25_est_cov_costs p75_est_cov_costs length_of_stay,fcolor(gs12) color(gs12)) ///
	     (line drg_price length_of_stay,lcolor(black)) ///
	     (line est_cov_costs length_of_stay,lpattern(dash) lcolor(black)) if length_of_stay<80 ///
	     & cDRG==871,legend(label(1 "Payment IQR") label(2 "Cost IQR") label(3 "Mean Payment") ///
	     label(4 "Mean Cost")) xline(20,lpattern(dash)) ytitle(`ytitle_rel') ///
	     xtitle(`xtitle_rel') `xrange_rel' `yrange_rel'
gr export "output/figures/cost_profits_LOS_DRG871.eps",replace
tabstat drg_price est_cov_costs if cDRG==871 &  length_of_stay>15 & length_of_stay<45, ///
	by(length_of_stay)
tabstat med_drg_price med_est_cov_costs if cDRG==871 &  length_of_stay>15 & length_of_stay<45 ///
	,by(length_of_stay) 


/**177**/
graph twoway (rarea p25_drg_price p75_drg_price length_of_stay,fcolor(gs15) color(gs15)) ///
	     (rarea p25_est_cov_costs p75_est_cov_costs length_of_stay,fcolor(gs12) color(gs12)) ///
	     (line drg_price length_of_stay,lcolor(black)) ///
	     (line est_cov_costs length_of_stay,lpattern(dash) lcolor(black)) if length_of_stay<80 ///
	     & cDRG==177,legend(label(1 "Payment IQR") label(2 "Cost IQR") label(3 "Mean Payment") ///
	     label(4 "Mean Cost")) xline(19,lpattern(dash)) ytitle(`ytitle_rel') ///
	     xtitle(`xtitle_rel') `xrange_rel' `yrange_rel'
gr export "output/figures/cost_profits_LOS_DRG177.eps",replace
tabstat drg_price est_cov_costs if cDRG==177 &  length_of_stay>15 & length_of_stay<45, ///
	by(length_of_stay)
tabstat med_drg_price med_est_cov_costs if cDRG==177 &  length_of_stay>15 & length_of_stay<45 ///
	,by(length_of_stay) 




restore
preserve
sort cDRG day2magic prov_fp

/**Collapsing by cDRG and length of stay but not by year**/
collapse (mean) drg_price est_cov_costs profit payoff_c1 payoff_c2 ///
	 (median) med_drg_price=drg_price med_est_cov_costs=est_cov_costs med_profit=profit ///
	 (p25) p25_drg_price=drg_price p25_est_cov_costs=est_cov_costs p25_profit=profit ///
	 (p75) p75_drg_price=drg_price p75_est_cov_costs=est_cov_costs p75_profit=profit,by(cDRG day2magic prov_fp)

sort cDRG day2magic prov_fp

local xrange_rel "xscale(range(-30 60)) xlabel(-30(30)60) xtick(-30(10)60)"
local yrange_rel "yscale(range(0 200000)) ylabel(0(50000)200000) ytick(0(50000)200000)"
local xtitle_rel "Day of Discharge Relative to Magic Day"
local ytitle_rel "Dollars"

/**207**/
graph twoway (line drg_price day2magic if prov_fp==1,lcolor(black) lpattern(solid)) ///
	     (line drg_price day2magic if prov_fp==0,lcolor(black) lpattern(dash)) ///
	     (line est_cov_costs day2magic if prov_fp==1,lcolor(black) lpattern(dash_dot)) ///
	     (line est_cov_costs day2magic if prov_fp==0,lpattern(longdash) lcolor(black)) if day2magic<60 ///
	     & cDRG==207,legend(label(1 "Payment IQR") label(2 "Cost IQR") label(3 "Mean Payment") ///
	     label(4 "Mean Cost")) xline(0,lpattern(dash)) ytitle(`ytitle_rel') ///
	     xtitle(`xtitle_rel') `xrange_rel' `yrange_rel'
gr export "output/figures/cost_for_non_profit_DRG207.eps",replace

restore
gen drg_price_fp = .
gen drg_price_nfp = .
gen est_cov_costs_fp = .
gen est_cov_costs_nfp = .

replace drg_price_fp = drg_price if prov_fp==1
replace drg_price_nfp = drg_price if prov_nfp==1
replace est_cov_costs_fp = est_cov_costs if prov_fp==1
replace est_cov_costs_nfp = est_cov_costs if prov_nfp==1

tabstat drg_price_fp drg_price_nfp,by(day2magic)
tabstat est_cov_costs_fp est_cov_costs_nfp,by(day2magic)

restore

log close
