/*****************************************************************
figures_histograms.do

This generates histogram figures for LTCH paper.
****************************************************************/
clear all
set more off
cap log close
set mem 12000m



cd ~/LTCH/
use data/MEDPAR_POS_ALL.dta
*drop if reimbursement_amount==0



local ymax 0.12
local ylabels "ylabel(0(.03).12) ytick(0(0.03).12)"
local xrange_abs "xscale(range(-30 60)) xlabel(-30(30)60) xtick(-30(10)60)"
local xlab_abs "Length of Stay"
local xlab_rel "Day of Discharge Relative to Magic Day"



/**Creating relative to magic day variable**/
gen day2magic = floor( (length_of_stay-sso_thresh+0.00001))

gen magic_day = ceil(sso_thresh)

sum magic_day if fyear==2004
local day2004 = r(mean)
sum magic_day if fyear==2013
local day2013 = r(mean)

preserve
local grp "207"
keep if cDRG==`grp'

/**Keeping only observations with length of stays less than the unconditional 
	95th percentile**/
sum length_of_stay if fyear>2002,d
keep if length_of_stay < r(p95)

graph twoway (histogram day2magic,discrete) if ///
	(disch_home==1|disch_othnf==1|disch_snf==1),xtitle(`xlab_rel') ///
	yscale(range(0 `ymax')) `ylabels' `xrange_abs'
*graph export "output/figures/Figure_2.pdf",replace

/**Figure 3**/

graph twoway (histogram length_of_stay,discrete /*fcolor(navy) lcolor(eltblue)*/) if fyear==2004 & (disch_home==1|disch_othnf==1|disch_snf==1),xtitle(`xlab_abs') yscale(range(0 `ymax')) `ylabels' xline(`day2004',lpattern(solid) lcolor(brown)) xline(`day2013',lpattern(dash) lcolor(brown))
gr export "output/figures/Figure3_2004.pdf",replace

graph twoway (histogram length_of_stay,discrete) (histogram length_of_stay if length_of_stay==`day2004',discrete /*color(navy)*/) ///
	(histogram length_of_stay if length_of_stay==`day2013',discrete color(red)) if fyear==2004 & (disch_home==1|disch_othnf==1|disch_snf==1),xtitle(`xlab_abs') yscale(range(0 `ymax')) `ylabels' 
gr export "output/figures/Figure3_2004_v2.pdf",replace

graph twoway (histogram length_of_stay,discrete /*fcolor(navy) lcolor(eltblue)*/) if fyear==2013 & (disch_home==1|disch_othnf==1|disch_snf==1),xtitle(`xlab_abs') yscale(range(0 `ymax')) `ylabels' xline(`day2013', lpattern(dash) lcolor(brown)) xline(`day2004',lpattern(solid) lcolor(brown))
gr export "output/figures/Figure3_2013.pdf",replace

graph twoway (histogram length_of_stay,discrete) (histogram length_of_stay if length_of_stay==`day2004',discrete color(navy)) ///
	(histogram length_of_stay if length_of_stay==`day2013',discrete color(red)) if fyear==2013 & (disch_home==1|disch_othnf==1|disch_snf==1),xtitle(`xlab_abs') yscale(range(0 `ymax')) `ylabels' 
gr export "output/figures/Figure3_2013_v2.pdf",replace

graph twoway (histogram length_of_stay,discrete /*fcolor(navy) lcolor(eltblue)*/) if fyear==2002 & (disch_home==1|disch_othnf==1|disch_snf==1),xtitle(`xlab_abs') yscale(range(0 `ymax')) `ylabels' xline(`day2013', lpattern(dash) lcolor(brown)) xline(`day2004',lpattern(solid) lcolor(brown))
gr export "output/figures/Figure3_2002.pdf",replace


drop if fyear==2002
/**Figure 4**/
graph twoway (histogram day2magic,discrete) if disch_home==1,xtitle(`xlab_rel') yscale(range(0 `ymax')) `ylabels' `xrange_abs'
gr export "output/figures/Figure4_home.pdf",replace

graph twoway (histogram day2magic,discrete) if disch_snf==1|disch_othnf==1,xtitle(`xlab_rel') yscale(range(0 `ymax')) `ylabels' `xrange_abs'
gr export "output/figures/Figure4_SNF.pdf",replace

graph twoway (histogram day2magic,discrete) if disch_stch==1|disch_othhosp==1,xtitle(`xlab_rel') yscale(range(0 `ymax')) `ylabels' `xrange_abs'
gr export "output/figures/Figure4_Hosp.pdf",replace

graph twoway (histogram day2magic,discrete) if disch_dead==1,xtitle(Day of Death Relative to Magic Day) yscale(range(0 `ymax')) `ylabels' `xrange_abs'
gr export "output/figures/Figure4_death.pdf",replace

/**Figure 5**/

graph twoway (histogram day2magic,discrete) if (disch_home==1|disch_othnf==1|disch_snf==1) & prov_fp==1,xtitle(`xlab_rel') yscale(range(0 `ymax')) `ylabels' `xrange_abs'
gr export "output/figures/Figure5_forprofit.pdf",replace

graph twoway (histogram day2magic,discrete) if (disch_home==1|disch_othnf==1|disch_snf==1) & prov_nfp==1,xtitle(`xlab_rel') yscale(range(0 `ymax')) `ylabels' `xrange_abs'
gr export "output/figures/Figure5_nonprofit.pdf",replace



/**Figure 6**/
graph twoway (histogram day2magic,discrete) if ///
	(disch_home==1|disch_othnf==1|disch_snf==1) & (preS==1 | preK==1), ///
	xtitle(`xlab_rel') yscale(range(0 `ymax')) `ylabels' `xrange_abs'
gr export "output/figures/Figure6_pre.pdf",replace

graph twoway (histogram day2magic,discrete) if ///
	(disch_home==1|disch_othnf==1|disch_snf==1) & (preS==2 | preK==2), ///
	xtitle(`xlab_rel') yscale(range(0 `ymax')) `ylabels' `xrange_abs'
gr export "output/figures/Figure6_post.pdf",replace


/**Figure 7**/

graph twoway (histogram day2magic,discrete) if (disch_home==1|disch_othnf==1|disch_snf==1) & aha_hwh==1,xtitle(`xlab_rel') yscale(range(0 `ymax')) `ylabels' `xrange_abs'
gr export "output/figures/Figure7_HWH'.pdf",replace

graph twoway (histogram day2magic,discrete) if (disch_home==1|disch_othnf==1|disch_snf==1) & aha_hwh==0,xtitle(`xlab_rel') yscale(range(0 `ymax')) `ylabels' `xrange_abs'
gr export "output/figures/Figure7_notHWH.pdf",replace


/**********Figure A1 and panels b, d, f from figure A2*****************/

restore
preserve
local grp "189"
keep if cDRG==`grp'

/**Keeping only observations with length of stays less than the unconditional 
	95th percentile**/
sum length_of_stay if fyear>2002,d
keep if length_of_stay < r(p95)

graph twoway (histogram length_of_stay,discrete /*fcolor(navy) lcolor(eltblue)*/) if fyear==2004 & (disch_home==1|disch_othnf==1|disch_snf==1),xtitle(`xlab_abs') yscale(range(0 `ymax')) `ylabels' xline(`day2004',lpattern(solid) lcolor(brown)) xline(`day2013',lpattern(dash) lcolor(brown))
gr export "output/figures/FigureA1_`grp'_2004.pdf",replace

graph twoway (histogram length_of_stay,discrete /*fcolor(navy) lcolor(eltblue)*/) if fyear==2013 & (disch_home==1|disch_othnf==1|disch_snf==1),xtitle(`xlab_abs') yscale(range(0 `ymax')) `ylabels' xline(`day2013', lpattern(dash) lcolor(brown)) xline(`day2004',lpattern(solid) lcolor(brown))
gr export "output/figures/FigureA1_`grp'_2013.pdf",replace

graph twoway (histogram day2magic,discrete) if (disch_home==1|disch_othnf==1|disch_snf==1),xtitle(`xlab_rel') yscale(range(0 `ymax')) `ylabels' `xrange_abs'
gr export "output/figures/FigureA2_hist_`grp''.pdf",replace


restore
preserve
local grp "871"
keep if cDRG==`grp'

/**Keeping only observations with length of stays less than the unconditional 
	95th percentile**/
sum length_of_stay if fyear>2002,d
keep if length_of_stay < r(p95)

graph twoway (histogram length_of_stay,discrete /*fcolor(navy) lcolor(eltblue)*/) if fyear==2004 & (disch_home==1|disch_othnf==1|disch_snf==1),xtitle(`xlab_abs') yscale(range(0 `ymax')) `ylabels' xline(`day2004',lpattern(solid) lcolor(brown)) xline(`day2013',lpattern(dash) lcolor(brown))
gr export "output/figures/FigureA1_`grp'_2004.pdf",replace

graph twoway (histogram length_of_stay,discrete /*fcolor(navy) lcolor(eltblue)*/) if fyear==2013 & (disch_home==1|disch_othnf==1|disch_snf==1),xtitle(`xlab_abs') yscale(range(0 `ymax')) `ylabels' xline(`day2013', lpattern(dash) lcolor(brown)) xline(`day2004',lpattern(solid) lcolor(brown))
gr export "output/figures/FigureA1_`grp'_2013.pdf",replace

graph twoway (histogram day2magic,discrete) if (disch_home==1|disch_othnf==1|disch_snf==1),xtitle(`xlab_rel') yscale(range(0 `ymax')) `ylabels' `xrange_abs'
gr export "output/figures/FigureA2_hist_`grp''.pdf",replace

restore
preserve
local grp "177"
keep if cDRG==`grp'

/**Keeping only observations with length of stays less than the unconditional 
	95th percentile**/
sum length_of_stay if fyear>2002,d
keep if length_of_stay < r(p95)

graph twoway (histogram length_of_stay,discrete /*fcolor(navy) lcolor(eltblue)*/) if fyear==2004 & (disch_home==1|disch_othnf==1|disch_snf==1),xtitle(`xlab_abs') yscale(range(0 `ymax')) `ylabels' xline(`day2004',lpattern(solid) lcolor(brown)) xline(`day2013',lpattern(dash) lcolor(brown))
gr export "output/figures/FigureA1_`grp'_2004.pdf",replace

graph twoway (histogram length_of_stay,discrete /*fcolor(navy) lcolor(eltblue)*/) if fyear==2013 & (disch_home==1|disch_othnf==1|disch_snf==1),xtitle(`xlab_abs') yscale(range(0 `ymax')) `ylabels' xline(`day2013', lpattern(dash) lcolor(brown)) xline(`day2004',lpattern(solid) lcolor(brown))
gr export "output/figures/FigureA1_`grp'_2013.pdf",replace

graph twoway (histogram day2magic,discrete) if (disch_home==1|disch_othnf==1|disch_snf==1),xtitle(`xlab_rel') yscale(range(0 `ymax')) `ylabels' `xrange_abs'
gr export "output/figures/FigureA2_hist_`grp''.pdf",replace




