/**********************************************************
table4_v2.do

This estimates the probit models that go into table 4 in the paper.

Absolute day hazard function is estimated using a quadratic functional form.
******************************************************************************/
clear all
cap log close
set more off
set mem 12000m
set matsize 11000

cd /net/storage-01/econ/research/jr139/LTCH/
use data/MEDPAR_POS_ALL.dta
log using work/tables/table4_v2.txt,replace text 
set linesize 200


/** Keeping live discharges to home or nursing facilities **/
drop if disch_dead==1 | disch_stch==1 | disch_othhosp==1

disp "*****************************************************"
disp "               DRG 207 "
disp "*****************************************************"
disp "  "

preserve

keep if cDRG==207

gen id = _n
expand length_of_stay
bysort id: gen day = _n
gen day2 = day*day
sort id
by id: gen first =_n==1
sum length_of_stay if first==1,d
keep if day<r(p95) 
bysort id (day): gen byte discharge = (_n==_N)
gen day2magic = -1*floor( (day-sso_thresh+0.00001))
qui tab day2magic,gen(temp)
egen d2m = group(temp*)
drop temp*

eststo: probit discharge ib16.d2m day day2 admin_emergency admin_urgent ///
		admin_elective admin_other, vce(cluster prov_id)
estimates store prob1


eststo: margins 29.d2m 30.d2m,at(day=27 day2=729) post
test _b[30.d2m] - _b[29.d2m] = 0
nlcom (_b[30.d2m] / _b[29.d2m])
testnl _b[30.d2m] / _b[29.d2m]=1
estimates restore prob1

eststo: margins 29.d2m 30.d2m,at(day=28 day2=784) post
test _b[30.d2m] - _b[29.d2m] = 0
nlcom (_b[30.d2m] / _b[29.d2m])
testnl _b[30.d2m] / _b[29.d2m]=1
estimates restore prob1

eststo: margins 29.d2m 30.d2m,at(day=29 day2=841) post
test _b[30.d2m] - _b[29.d2m] = 0
nlcom (_b[30.d2m] / _b[29.d2m])
testnl _b[30.d2m] / _b[29.d2m]=1
estimates restore prob1

eststo: margins 29.d2m 30.d2m,at(day=30 day2=900) post
test _b[30.d2m] - _b[29.d2m] = 0
nlcom (_b[30.d2m] / _b[29.d2m])
testnl _b[30.d2m] / _b[29.d2m]=1
estimates restore prob1

restore


disp "*****************************************************"
disp "               DRG 189 "
disp "*****************************************************"
disp "  "

preserve

keep if cDRG==189

gen id = _n
expand length_of_stay
bysort id: gen day = _n
gen day2 = day*day
sort id
by id: gen first =_n==1
sum length_of_stay if first==1,d
keep if day<r(p95) 
bysort id (day): gen byte discharge = (_n==_N)
gen day2magic = -1*floor( (day-sso_thresh+0.00001))
qui tab day2magic,gen(temp)
egen d2m = group(temp*)
drop temp*

eststo: probit discharge ib13.d2m day day2 admin_emergency admin_urgent ///
		admin_elective admin_other, vce(cluster prov_id)
estimates store prob1

eststo: margins 26.d2m 27.d2m,at(day=19 day2=361) post
test _b[27.d2m] - _b[26.d2m] = 0
nlcom (_b[27.d2m] / _b[26.d2m])
testnl _b[27.d2m] / _b[26.d2m]=1
estimates restore prob1

eststo: margins 26.d2m 27.d2m,at(day=20 day2=400) post
test _b[27.d2m] - _b[26.d2m] = 0
nlcom (_b[27.d2m] / _b[26.d2m])
testnl _b[27.d2m] / _b[26.d2m]=1
estimates restore prob1

eststo: margins 26.d2m 27.d2m,at(day=21 day2=441) post
test _b[27.d2m] - _b[26.d2m] = 0
nlcom (_b[27.d2m] / _b[26.d2m])
testnl _b[27.d2m] / _b[26.d2m]=1
estimates restore prob1

eststo: margins 26.d2m 27.d2m,at(day=22 day2=484) post
test _b[27.d2m] - _b[26.d2m] = 0
nlcom (_b[27.d2m] / _b[26.d2m])
testnl _b[27.d2m] / _b[26.d2m]=1
estimates restore prob1

eststo: margins 26.d2m 27.d2m,at(day=23 day2=529) post
test _b[27.d2m] - _b[26.d2m] = 0
nlcom (_b[27.d2m] / _b[26.d2m])
testnl _b[27.d2m] / _b[26.d2m]=1
estimates restore prob1

eststo: margins 26.d2m 27.d2m,at(day=24 day2=576) post
test _b[27.d2m] - _b[26.d2m] = 0
nlcom (_b[27.d2m] / _b[26.d2m])
testnl _b[27.d2m] / _b[26.d2m]=1
estimates restore prob1

eststo: margins 26.d2m 27.d2m,at(day=25 day2=625) post
test _b[27.d2m] - _b[26.d2m] = 0
nlcom (_b[27.d2m] / _b[26.d2m])
testnl _b[27.d2m] / _b[26.d2m]=1
estimates restore prob1

eststo: margins 26.d2m 27.d2m,at(day=26 day2=676) post
test _b[27.d2m] - _b[26.d2m] = 0
nlcom (_b[27.d2m] / _b[26.d2m])
testnl _b[27.d2m] / _b[26.d2m]=1
estimates restore prob1

eststo: margins 26.d2m 27.d2m,at(day=27 day2=729) post
test _b[27.d2m] - _b[26.d2m] = 0
nlcom (_b[27.d2m] / _b[26.d2m])
testnl _b[27.d2m] / _b[26.d2m]=1
estimates restore prob1

restore


disp "*****************************************************"
disp "               DRG 871 "
disp "*****************************************************"
disp "  "

preserve

keep if cDRG==871

gen id = _n
expand length_of_stay
bysort id: gen day = _n
gen day2 = day*day
sort id
by id: gen first =_n==1
sum length_of_stay if first==1,d
keep if day<r(p95) 
bysort id (day): gen byte discharge = (_n==_N)
gen day2magic = -1*floor( (day-sso_thresh+0.00001))
qui tab day2magic,gen(temp)
egen d2m = group(temp*)
drop temp*

eststo: probit discharge ib13.d2m day day2 admin_emergency admin_urgent ///
		admin_elective admin_other, vce(cluster prov_id)
estimates store prob1

eststo: margins 20.d2m 21.d2m,at(day=19 day2=361) post
test _b[21.d2m] - _b[20.d2m] = 0
nlcom (_b[21.d2m] / _b[20.d2m])
testnl _b[21.d2m] / _b[20.d2m]=1
estimates restore prob1

eststo: margins 20.d2m 21.d2m,at(day=20 day2=400) post
test _b[21.d2m] - _b[20.d2m] = 0
nlcom (_b[21.d2m] / _b[20.d2m])
testnl _b[21.d2m] / _b[20.d2m]=1
estimates restore prob1

eststo: margins 20.d2m 21.d2m,at(day=21 day2=441) post
test _b[21.d2m] - _b[20.d2m] = 0
nlcom (_b[21.d2m] / _b[20.d2m])
testnl _b[21.d2m] / _b[20.d2m]=1
estimates restore prob1

restore

disp "*****************************************************"
disp "               DRG 177 "
disp "*****************************************************"
disp "  "

preserve

keep if cDRG==177

gen id = _n
expand length_of_stay
bysort id: gen day = _n
gen day2 = day*day
sort id
by id: gen first =_n==1
sum length_of_stay if first==1,d
keep if day<r(p95) 
bysort id (day): gen byte discharge = (_n==_N)
gen day2magic = -1*floor( (day-sso_thresh+0.00001))
qui tab day2magic,gen(temp)
egen d2m = group(temp*)
drop temp*

eststo: probit discharge ib12.d2m day day2 admin_emergency admin_urgent ///
		admin_elective admin_other, vce(cluster prov_id)
estimates store prob1

eststo: margins 19.d2m 20.d2m,at(day=19 day2=361) post
test _b[20.d2m] - _b[19.d2m] = 0
nlcom (_b[20.d2m] / _b[19.d2m])
testnl _b[20.d2m] / _b[19.d2m]=1
estimates restore prob1

eststo: margins 19.d2m 20.d2m,at(day=20 day2=400) post
test _b[20.d2m] - _b[19.d2m] = 0
nlcom (_b[20.d2m] / _b[19.d2m])
testnl _b[20.d2m] / _b[19.d2m]=1
estimates restore prob1

restore

log close
