/*******************************************************************************
table5_v1.do

This estimates the probit models to generate table 5 from the paper--probit 
intracted with hospital characteristics.

*******************************************************************************/
clear all
cap log close
set more off
set mem 12000m
set matsize 11000

cd /net/storage-01/econ/research/jr139/LTCH/

use data/MEDPAR_POS_ALL.dta

log using work/tables/table5_v2.txt,replace text 
set linesize 200

destring(prov_id),replace


/** Keeping only DRG 207 **/
keep if cDRG==207

/**Dropping 2002, 2014 and 2015**/
drop if fyear==2002
drop if fyear>2013

/**Dropping observations with drg_price<=0**/
keep if drg_price>0

/** Expanding data **/
gen id = _n
expand length_of_stay
bysort id: gen day = _n
gen day2 = day*day
sort id
by id: gen first =_n==1
sum length_of_stay if first==1,d
keep if day<r(p95) /*& day>r(p5)*/
bysort id (day): gen byte discharge = (_n==_N)
gen day2magic = -1*floor( (day-sso_thresh+0.00001))
qui tab day2magic,gen(temp)
egen d2m = group(temp*)

drop if disch_dead==1 | disch_stch==1 | disch_othhosp==1


/** HWH **/
probit discharge aha_hwh#d2m day2 day , vce(cluster prov_id)
margins 1.aha_hwh#29.d2m 1.aha_hwh#30.d2m 0.aha_hwh#29.d2m 0.aha_hwh#30.d2m, ///
	at(day=29 day2=841) post
test (_b[0.aha_hwh#30.d2m] - _b[0.aha_hwh#29.d2m]) -  ///
	 (_b[1.aha_hwh#30.d2m] - _b[1.aha_hwh#29.d2m]) = 0
	 
nlcom  (_b[0.aha_hwh#30.d2m] / _b[0.aha_hwh#29.d2m])
testnl (_b[0.aha_hwh#30.d2m] / _b[0.aha_hwh#29.d2m]) = 1

nlcom  (_b[1.aha_hwh#30.d2m] / _b[1.aha_hwh#29.d2m])
testnl (_b[1.aha_hwh#30.d2m] / _b[1.aha_hwh#29.d2m]) = 1

nlcom (_b[0.aha_hwh#30.d2m] / _b[0.aha_hwh#29.d2m]) -  ///
	  (_b[1.aha_hwh#30.d2m] / _b[1.aha_hwh#29.d2m]) 
testnl (_b[0.aha_hwh#30.d2m] / _b[0.aha_hwh#29.d2m]) -  ///
	   (_b[1.aha_hwh#30.d2m] / _b[1.aha_hwh#29.d2m]) = 0
       
nlcom (_b[0.aha_hwh#30.d2m] / _b[0.aha_hwh#29.d2m]) /  ///
	  (_b[1.aha_hwh#30.d2m] / _b[1.aha_hwh#29.d2m]) 
testnl (_b[0.aha_hwh#30.d2m] / _b[0.aha_hwh#29.d2m]) /  ///
	   (_b[1.aha_hwh#30.d2m] / _b[1.aha_hwh#29.d2m]) = 1       
	   
/** For profit **/
probit discharge prov_fp#d2m day2 day , vce(cluster prov_id)
margins 1.prov_fp#29.d2m 1.prov_fp#30.d2m 0.prov_fp#29.d2m 0.prov_fp#30.d2m, ///
	at(day=29 day2=841) post
test (_b[0.prov_fp#30.d2m] - _b[0.prov_fp#29.d2m]) -  ///
	 (_b[1.prov_fp#30.d2m] - _b[1.prov_fp#29.d2m]) = 0
	 
nlcom  (_b[0.prov_fp#30.d2m] / _b[0.prov_fp#29.d2m])
testnl (_b[0.prov_fp#30.d2m] / _b[0.prov_fp#29.d2m]) = 1

nlcom  (_b[1.prov_fp#30.d2m] / _b[1.prov_fp#29.d2m])
testnl (_b[1.prov_fp#30.d2m] / _b[1.prov_fp#29.d2m]) = 1

nlcom (_b[0.prov_fp#30.d2m] / _b[0.prov_fp#29.d2m]) -  ///
	  (_b[1.prov_fp#30.d2m] / _b[1.prov_fp#29.d2m]) 
testnl (_b[0.prov_fp#30.d2m] / _b[0.prov_fp#29.d2m]) -  ///
	   (_b[1.prov_fp#30.d2m] / _b[1.prov_fp#29.d2m]) = 0
       
nlcom (_b[0.prov_fp#30.d2m] / _b[0.prov_fp#29.d2m]) /  ///
	  (_b[1.prov_fp#30.d2m] / _b[1.prov_fp#29.d2m]) 
testnl (_b[0.prov_fp#30.d2m] / _b[0.prov_fp#29.d2m]) /  ///
	   (_b[1.prov_fp#30.d2m] / _b[1.prov_fp#29.d2m]) = 1       

cap drop chain
gen chain = 0
replace chain = 1 if select==1
replace chain = 2 if kindred==1
/** CHAIN **/
probit discharge chain#d2m day2 day , vce(cluster prov_id)
margins 1.chain#29.d2m 1.chain#30.d2m 0.chain#29.d2m 0.chain#30.d2m ///
	2.chain#29.d2m 2.chain#30.d2m, at(day=29 day2=841) post
test (_b[0.chain#30.d2m] - _b[0.chain#29.d2m]) -  ///
	 (_b[1.chain#30.d2m] - _b[1.chain#29.d2m]) = 0
test (_b[0.chain#30.d2m] - _b[0.chain#29.d2m]) -  ///
	 (_b[2.chain#30.d2m] - _b[2.chain#29.d2m]) = 0	
test (_b[2.chain#30.d2m] - _b[2.chain#29.d2m]) -  ///
	 (_b[1.chain#30.d2m] - _b[1.chain#29.d2m]) = 0	 
	 
nlcom  (_b[0.chain#30.d2m] / _b[0.chain#29.d2m])
testnl (_b[0.chain#30.d2m] / _b[0.chain#29.d2m]) = 1

nlcom  (_b[1.chain#30.d2m] / _b[1.chain#29.d2m])
testnl (_b[1.chain#30.d2m] / _b[1.chain#29.d2m]) = 1

nlcom  (_b[2.chain#30.d2m] / _b[2.chain#29.d2m])
testnl (_b[2.chain#30.d2m] / _b[2.chain#29.d2m]) = 1

nlcom (_b[0.chain#30.d2m] / _b[0.chain#29.d2m]) -  ///
	  (_b[1.chain#30.d2m] / _b[1.chain#29.d2m]) 
testnl (_b[0.chain#30.d2m] / _b[0.chain#29.d2m]) -  ///
	   (_b[1.chain#30.d2m] / _b[1.chain#29.d2m]) = 0
	   
nlcom (_b[0.chain#30.d2m] / _b[0.chain#29.d2m]) -  ///
	  (_b[2.chain#30.d2m] / _b[2.chain#29.d2m]) 
testnl (_b[0.chain#30.d2m] / _b[0.chain#29.d2m]) -  ///
	   (_b[2.chain#30.d2m] / _b[2.chain#29.d2m]) = 0
	   
nlcom (_b[2.chain#30.d2m] / _b[2.chain#29.d2m]) -  ///
	  (_b[1.chain#30.d2m] / _b[1.chain#29.d2m]) 
testnl (_b[2.chain#30.d2m] / _b[2.chain#29.d2m]) -  ///
	   (_b[1.chain#30.d2m] / _b[1.chain#29.d2m]) = 0

nlcom (_b[0.chain#30.d2m] / _b[0.chain#29.d2m]) /  ///
	  (_b[1.chain#30.d2m] / _b[1.chain#29.d2m]) 
testnl (_b[0.chain#30.d2m] / _b[0.chain#29.d2m]) /  ///
	   (_b[1.chain#30.d2m] / _b[1.chain#29.d2m]) = 1
	   
nlcom (_b[0.chain#30.d2m] / _b[0.chain#29.d2m]) /  ///
	  (_b[2.chain#30.d2m] / _b[2.chain#29.d2m]) 
testnl (_b[0.chain#30.d2m] / _b[0.chain#29.d2m]) /  ///
	   (_b[2.chain#30.d2m] / _b[2.chain#29.d2m]) = 1
	   
nlcom (_b[2.chain#30.d2m] / _b[2.chain#29.d2m]) /  ///
	  (_b[1.chain#30.d2m] / _b[1.chain#29.d2m]) 
testnl (_b[2.chain#30.d2m] / _b[2.chain#29.d2m]) /  ///
	   (_b[1.chain#30.d2m] / _b[1.chain#29.d2m]) = 1       
	   
/** Kindred or Select Pooled **/
gen KS = (kindred==1) | (select==1)
probit discharge KS#d2m day2 day , vce(cluster prov_id)
margins 1.KS#29.d2m 1.KS#30.d2m 0.KS#29.d2m 0.KS#30.d2m ///
	, at(day=29 day2=841) post
test (_b[0.KS#30.d2m] - _b[0.KS#29.d2m]) -  ///
	 (_b[1.KS#30.d2m] - _b[1.KS#29.d2m]) = 0
 
	 
nlcom  (_b[0.KS#30.d2m] / _b[0.KS#29.d2m])
testnl (_b[0.KS#30.d2m] / _b[0.KS#29.d2m]) = 1

nlcom  (_b[1.KS#30.d2m] / _b[1.KS#29.d2m])
testnl (_b[1.KS#30.d2m] / _b[1.KS#29.d2m]) = 1

nlcom (_b[0.KS#30.d2m] / _b[0.KS#29.d2m]) -  ///
	  (_b[1.KS#30.d2m] / _b[1.KS#29.d2m]) 
testnl (_b[0.KS#30.d2m] / _b[0.KS#29.d2m]) -  ///
	   (_b[1.KS#30.d2m] / _b[1.KS#29.d2m]) = 1
	   
nlcom (_b[0.KS#30.d2m] / _b[0.KS#29.d2m]) /  ///
	  (_b[1.KS#30.d2m] / _b[1.KS#29.d2m]) 
testnl (_b[0.KS#30.d2m] / _b[0.KS#29.d2m]) /  ///
	   (_b[1.KS#30.d2m] / _b[1.KS#29.d2m]) = 1
	   

/** SELECT **/
probit discharge select#d2m day2 day , vce(cluster prov_id)
margins 1.select#29.d2m 1.select#30.d2m 0.select#29.d2m 0.select#30.d2m, ///
	at(day=29 day2=841) post
test (_b[0.select#30.d2m] - _b[0.select#29.d2m]) -  ///
	 (_b[1.select#30.d2m] - _b[1.select#29.d2m]) = 0
	 
nlcom  (_b[0.select#30.d2m] / _b[0.select#29.d2m])
testnl (_b[0.select#30.d2m] / _b[0.select#29.d2m]) = 1

nlcom  (_b[1.select#30.d2m] / _b[1.select#29.d2m])
testnl (_b[1.select#30.d2m] / _b[1.select#29.d2m]) = 1

nlcom (_b[0.select#30.d2m] / _b[0.select#29.d2m]) -  ///
	  (_b[1.select#30.d2m] / _b[1.select#29.d2m]) 
testnl (_b[0.select#30.d2m] / _b[0.select#29.d2m]) -  ///
	   (_b[1.select#30.d2m] / _b[1.select#29.d2m]) = 0
	   
nlcom (_b[0.select#30.d2m] / _b[0.select#29.d2m]) /  ///
	  (_b[1.select#30.d2m] / _b[1.select#29.d2m]) 
testnl (_b[0.select#30.d2m] / _b[0.select#29.d2m]) /  ///
	   (_b[1.select#30.d2m] / _b[1.select#29.d2m]) = 1       
       
/** KINDRED **/
probit discharge kindred#d2m day2 day , vce(cluster prov_id)
margins 1.kindred#29.d2m 1.kindred#30.d2m 0.kindred#29.d2m 0.kindred#30.d2m, ///
	at(day=29 day2=841) post
test (_b[0.kindred#30.d2m] - _b[0.kindred#29.d2m]) -  ///
	 (_b[1.kindred#30.d2m] - _b[1.kindred#29.d2m]) = 0
	 
nlcom  (_b[0.kindred#30.d2m] / _b[0.kindred#29.d2m])
testnl (_b[0.kindred#30.d2m] / _b[0.kindred#29.d2m]) = 1

nlcom  (_b[1.kindred#30.d2m] / _b[1.kindred#29.d2m])
testnl (_b[1.kindred#30.d2m] / _b[1.kindred#29.d2m]) = 1

nlcom (_b[0.kindred#30.d2m] / _b[0.kindred#29.d2m]) -  ///
	  (_b[1.kindred#30.d2m] / _b[1.kindred#29.d2m]) 
testnl (_b[0.kindred#30.d2m] / _b[0.kindred#29.d2m]) -  ///
	   (_b[1.kindred#30.d2m] / _b[1.kindred#29.d2m]) = 0

nlcom (_b[0.kindred#30.d2m] / _b[0.kindred#29.d2m]) /  ///
	  (_b[1.kindred#30.d2m] / _b[1.kindred#29.d2m]) 
testnl (_b[0.kindred#30.d2m] / _b[0.kindred#29.d2m]) /  ///
	   (_b[1.kindred#30.d2m] / _b[1.kindred#29.d2m]) = 1
	   
/** SELECT ACQUISITION **/
probit discharge preS#d2m day2 day , vce(cluster prov_id)
margins 1.preS#29.d2m 1.preS#30.d2m 2.preS#29.d2m 2.preS#30.d2m, ///
	at(day=29 day2=841) post
test (_b[2.preS#30.d2m] - _b[2.preS#29.d2m]) -  ///
	 (_b[1.preS#30.d2m] - _b[1.preS#29.d2m]) = 0
	 
nlcom  (_b[2.preS#30.d2m] / _b[2.preS#29.d2m])
testnl (_b[2.preS#30.d2m] / _b[2.preS#29.d2m]) = 1

nlcom  (_b[1.preS#30.d2m] / _b[1.preS#29.d2m])
testnl (_b[1.preS#30.d2m] / _b[1.preS#29.d2m]) = 1

nlcom (_b[2.preS#30.d2m] / _b[2.preS#29.d2m]) -  ///
	  (_b[1.preS#30.d2m] / _b[1.preS#29.d2m]) 
testnl (_b[2.preS#30.d2m] / _b[2.preS#29.d2m]) -  ///
	   (_b[1.preS#30.d2m] / _b[1.preS#29.d2m]) = 0

nlcom (_b[2.preS#30.d2m] / _b[2.preS#29.d2m]) /  ///
	  (_b[1.preS#30.d2m] / _b[1.preS#29.d2m]) 
testnl (_b[2.preS#30.d2m] / _b[2.preS#29.d2m]) /  ///
	   (_b[1.preS#30.d2m] / _b[1.preS#29.d2m]) = 1       
       
/** KINDRED ACQUISITION **/
probit discharge preK#d2m day2 day , vce(cluster prov_id)
margins 1.preK#29.d2m 1.preK#30.d2m 2.preK#29.d2m 2.preK#30.d2m, ///
	at(day=29 day2=841) post
test (_b[2.preK#30.d2m] - _b[2.preK#29.d2m]) -  ///
	 (_b[1.preK#30.d2m] - _b[1.preK#29.d2m]) = 0
	 
nlcom  (_b[2.preK#30.d2m] / _b[2.preK#29.d2m])
testnl (_b[2.preK#30.d2m] / _b[2.preK#29.d2m]) = 1

nlcom  (_b[1.preK#30.d2m] / _b[1.preK#29.d2m])
testnl (_b[1.preK#30.d2m] / _b[1.preK#29.d2m]) = 1

nlcom (_b[2.preK#30.d2m] / _b[2.preK#29.d2m]) -  ///
	  (_b[1.preK#30.d2m] / _b[1.preK#29.d2m]) 
testnl (_b[2.preK#30.d2m] / _b[2.preK#29.d2m]) -  ///
	   (_b[1.preK#30.d2m] / _b[1.preK#29.d2m]) = 0	

nlcom (_b[2.preK#30.d2m] / _b[2.preK#29.d2m]) /  ///
	  (_b[1.preK#30.d2m] / _b[1.preK#29.d2m]) 
testnl (_b[2.preK#30.d2m] / _b[2.preK#29.d2m]) /  ///
	   (_b[1.preK#30.d2m] / _b[1.preK#29.d2m]) = 1	
	   
/**POOLED ACQUISITION**/
gen preacq = .
replace preacq = 0 if preK==0 | preS==0
replace preacq = 1 if preK==1 | preS==1
replace preacq = 2 if preK==2 | preS==2

probit discharge preacq#d2m day2 day , vce(cluster prov_id)
margins 0.preacq#29.d2m 0.preacq#30.d2m 1.preacq#29.d2m 1.preacq#30.d2m ///
	2.preacq#29.d2m 2.preacq#30.d2m, ///
	at(day=29 day2=841) post
test (_b[2.preacq#30.d2m] - _b[2.preacq#29.d2m]) -  ///
	 (_b[1.preacq#30.d2m] - _b[1.preacq#29.d2m]) = 0
	 
nlcom  (_b[2.preacq#30.d2m] / _b[2.preacq#29.d2m])
testnl (_b[2.preacq#30.d2m] / _b[2.preacq#29.d2m]) = 1

nlcom  (_b[1.preacq#30.d2m] / _b[1.preacq#29.d2m])
testnl (_b[1.preacq#30.d2m] / _b[1.preacq#29.d2m]) = 1

nlcom  (_b[0.preacq#30.d2m] / _b[0.preacq#29.d2m])
testnl (_b[0.preacq#30.d2m] / _b[0.preacq#29.d2m]) = 1

nlcom (_b[2.preacq#30.d2m] / _b[2.preacq#29.d2m]) -  ///
	  (_b[1.preacq#30.d2m] / _b[1.preacq#29.d2m]) 
testnl (_b[2.preacq#30.d2m] / _b[2.preacq#29.d2m]) -  ///
	   (_b[1.preacq#30.d2m] / _b[1.preacq#29.d2m]) = 0	
	   
nlcom (_b[1.preacq#30.d2m] / _b[1.preacq#29.d2m]) -  ///
	  (_b[0.preacq#30.d2m] / _b[0.preacq#29.d2m]) 
testnl (_b[1.preacq#30.d2m] / _b[1.preacq#29.d2m]) -  ///
	   (_b[0.preacq#30.d2m] / _b[0.preacq#29.d2m]) = 0

nlcom (_b[2.preacq#30.d2m] / _b[2.preacq#29.d2m]) /  ///
	  (_b[1.preacq#30.d2m] / _b[1.preacq#29.d2m]) 
testnl (_b[2.preacq#30.d2m] / _b[2.preacq#29.d2m]) /  ///
	   (_b[1.preacq#30.d2m] / _b[1.preacq#29.d2m]) = 11	
	   
nlcom (_b[1.preacq#30.d2m] / _b[1.preacq#29.d2m]) /  ///
	  (_b[0.preacq#30.d2m] / _b[0.preacq#29.d2m]) 
testnl (_b[1.preacq#30.d2m] / _b[1.preacq#29.d2m]) /  ///
	   (_b[0.preacq#30.d2m] / _b[0.preacq#29.d2m]) = 1   

/***Race***/
gen race = 0 
replace race = 1 if black==1
replace race = 2 if asian==1 | hisp==1 | natam==1 | rcoth==1  

probit discharge race#d2m day2 day , vce(cluster prov_id) 
margins 0.race#29.d2m 0.race#30.d2m 1.race#29.d2m 1.race#30.d2m ///
	2.race#29.d2m 2.race#30.d2m,at(day=29 day2=841) post  
 
nlcom  (_b[0.race#30.d2m] / _b[0.race#29.d2m])
testnl (_b[0.race#30.d2m] / _b[0.race#29.d2m]) = 1

nlcom  (_b[1.race#30.d2m] / _b[1.race#29.d2m])
testnl (_b[1.race#30.d2m] / _b[1.race#29.d2m]) = 1

nlcom  (_b[2.race#30.d2m] / _b[2.race#29.d2m])
testnl (_b[2.race#30.d2m] / _b[2.race#29.d2m]) = 1   

nlcom (_b[1.race#30.d2m] / _b[1.race#29.d2m]) - ///
	(_b[0.race#30.d2m] / _b[0.race#29.d2m]) 
testnl (_b[1.race#30.d2m] / _b[1.race#29.d2m]) - ///
	(_b[0.race#30.d2m] / _b[0.race#29.d2m]) = 1  
	   
nlcom (_b[2.race#30.d2m] / _b[2.race#29.d2m]) -  ///
	  (_b[0.race#30.d2m] / _b[0.race#29.d2m]) 
testnl (_b[2.race#30.d2m] / _b[2.race#29.d2m]) -  ///
	   (_b[0.race#30.d2m] / _b[0.race#29.d2m]) = 1   
       
nlcom (_b[1.race#30.d2m] / _b[1.race#29.d2m]) / ///
	(_b[0.race#30.d2m] / _b[0.race#29.d2m]) 
testnl (_b[1.race#30.d2m] / _b[1.race#29.d2m]) / ///
	(_b[0.race#30.d2m] / _b[0.race#29.d2m]) = 1  
	   
nlcom (_b[2.race#30.d2m] / _b[2.race#29.d2m]) /  ///
	  (_b[0.race#30.d2m] / _b[0.race#29.d2m]) 
testnl (_b[2.race#30.d2m] / _b[2.race#29.d2m]) /  ///
	   (_b[0.race#30.d2m] / _b[0.race#29.d2m]) = 1       

/** Age **/
gen age = 0
replace age = 1 if agegrp>3

probit discharge age#d2m day2 day , vce(cluster prov_id) // use ## or #
margins 1.age#29.d2m 1.age#30.d2m 0.age#29.d2m 0.age#30.d2m, ///
	at(day=29 day2=841) post
test (_b[0.age#30.d2m] - _b[0.age#29.d2m]) -  ///
	 (_b[1.age#30.d2m] - _b[1.age#29.d2m]) = 0
	 
nlcom  (_b[0.age#30.d2m] / _b[0.age#29.d2m])
testnl (_b[0.age#30.d2m] / _b[0.age#29.d2m]) = 1

nlcom  (_b[1.age#30.d2m] / _b[1.age#29.d2m])
testnl (_b[1.age#30.d2m] / _b[1.age#29.d2m]) = 1

nlcom (_b[1.age#30.d2m] / _b[1.age#29.d2m]) /  ///
	  (_b[0.age#30.d2m] / _b[0.age#29.d2m]) 
testnl (_b[1.age#30.d2m] / _b[1.age#29.d2m]) /  ///
	   (_b[0.age#30.d2m] / _b[0.age#29.d2m]) = 1
	   
/** Sex **/
probit discharge male#d2m day2 day , vce(cluster prov_id)
margins 1.male#29.d2m 1.male#30.d2m 0.male#29.d2m 0.male#30.d2m, ///
	at(day=29 day2=841) post
test (_b[0.male#30.d2m] - _b[0.male#29.d2m]) -  ///
	 (_b[1.male#30.d2m] - _b[1.male#29.d2m]) = 0
	 
nlcom  (_b[0.male#30.d2m] / _b[0.male#29.d2m])
testnl (_b[0.male#30.d2m] / _b[0.male#29.d2m]) = 1

nlcom  (_b[1.male#30.d2m] / _b[1.male#29.d2m])
testnl (_b[1.male#30.d2m] / _b[1.male#29.d2m]) = 1

nlcom (_b[1.male#30.d2m] / _b[1.male#29.d2m]) /  ///
	  (_b[0.male#30.d2m] / _b[0.male#29.d2m]) 
testnl (_b[1.male#30.d2m] / _b[1.male#29.d2m]) /  ///
	   (_b[0.male#30.d2m] / _b[0.male#29.d2m]) = 1       