/*****************************************************************
table3_v1.do

This generates the data for the descriptive table in the paper.
*****************************************************************/
clear all
set more off
cap log close
set mem 12000m

cd /econ/research/jr139/LTCH/

log using work/tables/tables3_v1.txt,text replace
use data/MEDPAR_POS_ALL.dta
*drop if reimbursement_amount==0
/** DRG 207 **/
gen cDRG=.
replace cDRG = 207 if fyear<=2006 & drg=="475"
replace cDRG = 207 if fyear==2007 & drg=="565"
replace cDRG = 207 if fyear>=2008 & drg=="207"

keep if cDRG==207
 
/**Keeping only observations with length of stays less than the unconditional 
	95th percentile**/
sum length_of_stay,d
keep if length_of_stay<r(p95)

/*keep if disch_home*/


/**Creating relative to magic day variable**/
gen day2magic = floor( (length_of_stay-sso_thresh+0.00001))

sort fyear prov_id
gen pat_id = _n
gen T = 45
expand T

sort pat_id length_of_stay
sort pat_id
by pat_id: gen t=_n

gen discharge = (length_of_stay==t)

gen yr20042013 = .
replace yr20042013 = 0 if fyear==2004
replace yr20042013 = 1 if fyear==2013

gen magic_day = t==ceil(sso_thresh)

gen prov_fpnfp = .
replace prov_fpnfp = 1 if prov_fp==1
replace prov_fpnfp = 0 if prov_nfp==1

gen destination = (disch_home==1)
replace destination = 2 if disch_snf==1 | disch_othnf==1
replace destination = 3 if disch_stch==1|disch_othhosp==1
replace destination = 4 if disch_dead==1


gen ks = kindred==1 | select==1

/*
sort prov_id fyear
by prov_id: egen everK = max(kindred)
by prov_id: egen everS = max(select)
by prov_id: egen enK = min(kindred)
by prov_id: egen enS = min(select)
replace enK = 1-enK
replace enS = 1-enS

gen preK = everK*enK*(1-kindred)
gen preS = everS*enS*(1-select)
gen postK = everK*enK*kindred
gen postS = everS*enS*select

gen postKS = .
replace postKS = 1 if postK==1 | postS==1
replace postKS = 0 if preK==1 | preS==1
*/



/** Discharge destination **/
reg discharge magic_day##destination if (t==ceil(sso_thresh) | t==floor(sso_thresh))

test 1.magic_day + 1.magic_day#1.destination = 0
test 1.magic_day + 1.magic_day#2.destination = 0
test 1.magic_day + 1.magic_day#3.destination = 0
test 1.magic_day + 1.magic_day#4.destination = 0

test 1.magic_day#1.destination = 1.magic_day#2.destination 
test 1.magic_day#1.destination = 1.magic_day#3.destination 
test 1.magic_day#1.destination = 1.magic_day#4.destination 

testnl (_b[_cons]+_b[1.destination]+_b[1.magic_day]+_b[1.magic_day#1.destination])/(_b[_cons]+_b[1.destination]) = 1
testnl (_b[_cons]+_b[2.destination]+_b[1.magic_day]+_b[1.magic_day#2.destination])/(_b[_cons]+_b[2.destination]) = 1
testnl (_b[_cons]+_b[3.destination]+_b[1.magic_day]+_b[1.magic_day#3.destination])/(_b[_cons]+_b[3.destination]) = 1
testnl (_b[_cons]+_b[4.destination]+_b[1.magic_day]+_b[1.magic_day#4.destination])/(_b[_cons]+_b[4.destination]) = 1

testnl (_b[_cons]+_b[1.destination]+_b[1.magic_day]+_b[1.magic_day#1.destination])/(_b[_cons]+_b[1.destination]) - ///
       (_b[_cons]+_b[2.destination]+_b[1.magic_day]+_b[1.magic_day#2.destination])/(_b[_cons]+_b[2.destination]) = 0
testnl (_b[_cons]+_b[1.destination]+_b[1.magic_day]+_b[1.magic_day#1.destination])/(_b[_cons]+_b[1.destination]) - ///
       (_b[_cons]+_b[3.destination]+_b[1.magic_day]+_b[1.magic_day#3.destination])/(_b[_cons]+_b[3.destination]) = 0
testnl (_b[_cons]+_b[1.destination]+_b[1.magic_day]+_b[1.magic_day#1.destination])/(_b[_cons]+_b[1.destination]) - ///
       (_b[_cons]+_b[4.destination]+_b[1.magic_day]+_b[1.magic_day#4.destination])/(_b[_cons]+_b[4.destination]) = 0


/** 2004 v 2013 **/
reg discharge magic_day##yr20042013 if disch_home==1 |disch_othnf==1 | ///
	disch_snf==1 & (t==ceil(sso_thresh) | t==floor(sso_thresh))
test 1.magic_day + 1.magic_day#1.yr20042013 = 0


/**For or not for profit **/
reg discharge magic_day##prov_fpnfp if (disch_home==1|disch_othnf==1|disch_snf==1) ///
	& (t==ceil(sso_thresh) | t==floor(sso_thresh))
test 1.magic_day + 1.magic_day#1.prov_fpnfp = 0

/**Kindred or Select**/
reg discharge magic_day##ks if (disch_home==1|disch_othnf==1|disch_snf==1) ///
	& (t==ceil(sso_thresh) | t==floor(sso_thresh))
test 1.magic_day + 1.magic_day#1.ks = 0

/**Select**/
reg discharge magic_day##select if (disch_home==1|disch_othnf==1|disch_snf==1) ///
	& (t==ceil(sso_thresh) | t==floor(sso_thresh))
test 1.magic_day + 1.magic_day#1.select = 0

/**Kindred**/
reg discharge magic_day##kindred if (disch_home==1|disch_othnf==1|disch_snf==1) ///
	& (t==ceil(sso_thresh) | t==floor(sso_thresh))
test 1.magic_day + 1.magic_day#1.kindred = 0

/**After Kindred Acquisition**/
reg discharge magic_day##preK if (disch_home==1|disch_othnf==1|disch_snf==1) ///
	& preK~=0 & (t==ceil(sso_thresh) | t==floor(sso_thresh))
test 1.magic_day + 1.magic_day#2.preK = 0
test 1.magic_day + 1.magic_day#2.preK = 0

/**After Kindred Divestiture**/
reg discharge magic_day##postK if (disch_home==1|disch_othnf==1|disch_snf==1) ///
	& postK~=0 & (t==ceil(sso_thresh) | t==floor(sso_thresh))
test 1.magic_day + 1.magic_day#1.postK = 0
test 1.magic_day + 1.magic_day#1.postK = 0

/**After Select Acquisition**/
reg discharge magic_day##preS if (disch_home==1|disch_othnf==1|disch_snf==1) ///
	& preS~=0 & (t==ceil(sso_thresh) | t==floor(sso_thresh))
test 1.magic_day + 1.magic_day#2.preS = 0
test 1.magic_day + 1.magic_day#2.preS = 0

/**Kindred and Select Acquisitions Pooled**/
gen preKS = .
replace preKS = 0 if preK==0 | preS==0
replace preKS = 1 if preK==1 | preS==1
replace preKS = 2 if preK==2 | preS==2

reg discharge magic_day##preKS if (disch_home==1|disch_othnf==1|disch_snf==1) ///
	& preKS~=0 & (t==ceil(sso_thresh) | t==floor(sso_thresh))
test 1.magic_day + 1.magic_day#2.preKS = 0
test 1.magic_day + 1.magic_day#2.preKS = 0

/** Colocated and not colocated **/
reg discharge magic_day##aha_hwh if (disch_home==1|disch_othnf==1|disch_snf==1) ///
	& (t==ceil(sso_thresh) | t==floor(sso_thresh))
test 1.magic_day + 1.magic_day#1.aha_hwh = 0

testnl (_b[_cons]+_b[0.aha_hwh]+_b[1.magic_day]+_b[1.magic_day#0.aha_hwh])/(_b[_cons]+_b[0.aha_hwh]) = 1
testnl (_b[_cons]+_b[1.aha_hwh]+_b[1.magic_day]+_b[1.magic_day#1.aha_hwh])/(_b[_cons]+_b[1.aha_hwh]) = 1

testnl (_b[_cons]+_b[0.aha_hwh]+_b[1.magic_day]+_b[1.magic_day#0.aha_hwh])/(_b[_cons]+_b[0.aha_hwh]) - ///
       (_b[_cons]+_b[1.aha_hwh]+_b[1.magic_day]+_b[1.magic_day#1.aha_hwh])/(_b[_cons]+_b[1.aha_hwh]) = 0

log close
