/*****************************************************************
tables1_and_2.do

Generates summary statistics for paper.
******************************************************************/
clear all
set more off
cap log close
set mem 12000m

cd ~/LTCH/

log using work/tables/tables1_and_2.txt,text replace
/************************************************
	SWITCHES
************************************************/
local patient_sum_stat = 1
local hosp_sum_stat = 0

if `patient_sum_stat'==1 {

use data/MEDPAR_POS_ALL.dta
*drop if reimbursement_amount==0

sort drg fyear length_of_stay

gen cDRG = 0
/** DRG 207 **/
replace cDRG = 207 if fyear<=2006 & drg=="475"
replace cDRG = 207 if fyear==2007 & drg=="565"
replace cDRG = 207 if fyear>=2008 & drg=="207"

/** DRG 189 **/
replace cDRG = 189 if fyear<=2007 & drg=="87"
replace cDRG = 189 if fyear>2007  & drg=="189"

/** DRG 871 **/
replace cDRG = 871 if fyear<=2006 & drg=="416"
replace cDRG = 871 if fyear==2007 & drg=="576"
replace cDRG = 871 if fyear>=2008 & drg=="871"

/** DRG 177--This one doesn't work perfectly but this is as good as 
					it gets (cc/MCC split in 2008)**/
replace cDRG = 177 if fyear<=2007 & drg=="79"
replace cDRG = 177 if fyear>=2008 & drg=="177"

/*keep if cDRG~=0*/

gen profit = drg_price-est_cov_costs
gen disch_hosp = disch_stch+disch_othhosp
gen disch_nurse = disch_snf+disch_othnf

gen source_community = source_of_admission=="1" | source_of_admission=="2"
gen source_nursing = source_of_admission=="5" | source_of_admission=="6"
gen source_hosp = source_of_admission=="4" 
gen source_other = source_of_admission=="3" | source_of_admission=="7" | source_of_admission=="8" | ///
		   source_of_admission=="9"

gen age1_24  = agegrp==1
gen age25_44 = agegrp==2
gen age45_64 = agegrp==3
gen age65_74 = (agegrp==4)|(agegrp==5)
gen age75_84 = (agegrp==6)|(agegrp==7)
gen age85    = (agegrp==8)|(agegrp==9)

gen post_md = length_of_stay>sso_thresh




/*********************
		LABELS
		************************/
lab var length_of_stay "Length of Stay"
lab var drg_price "Total Payment"
lab var reimbursement_amount "Amount Paid by Medicare"
lab var est_tot_costs "Estimated Costs"
lab var est_cov_costs "Estimated Costs"
lab var disch_alive "Portion Discharged Alive"
lab var disch_home "Portion Discharged to Home Care"
lab var disch_hosp "Portion Discharged to Hospital"
lab var disch_nurse "Portion Discharged to Nursing Facility"
lab var admin_emergency "Admission Type:  Emergency"
lab var admin_urgent "Admission Type: Urgent"
lab var admin_elective "Admission Type: Elective"
lab var admin_other "Admission Type: Other"
lab var source_community "Admitted from Community"
lab var source_nursing "Admitted from Nursing Facility"
lab var source_hosp "Admitted from General Hospital"
lab var source_other "Admitted from Other Source"
lab var male "Male"
lab var white "White"
lab var black "Black"
lab var asian "Asian"
lab var hisp "Hispanic"
lab var age1_24 "Age less than 25"
lab var age25_44 "Ave between 25 and 44"
lab var age45_64 "Age between 45 and 64"
lab var age65_74 "Age between 65 and 74"
lab var age75_84 "Age bewteen 75 and 84"
lab var age85 "Age over 85"
lab var post_md "Released on or after magic day"

/*****************************************************************
summary statistics for entire sample
*****************************************************************/

/*****Table A1: Patient Summary Statistics, All**********/
sum length_of_stay drg_price reimbursement_amount est_cov_costs disch_alive disch_dead disch_home disch_hosp ///
	disch_nurse admin_emergency admin_urgent admin_elective admin_other ///
	source_community source_nursing source_hosp source_other male white black asian hisp ///
	age1_24 age25_44 age45_64 age65_74 age75_84 age85 drg_price est_cov_costs post_md ///
	disch_home disch_hosp disch_nurse disch_alive

sutex length_of_stay drg_price reimbursement_amount est_cov_costs disch_alive disch_dead disch_home disch_hosp ///
	disch_nurse admin_emergency admin_urgent admin_elective admin_other ///
	source_community source_nursing source_hosp source_other male white black asian hisp ///
	age1_24 age25_44 age45_64 age65_74 age75_84 age85 drg_price est_cov_costs post_md ///
	disch_home disch_hosp disch_nurse disch_alive, digits(3) labels

/**********Table A2: Patient Summary Statistics, DRG 207**********/
sum length_of_stay drg_price reimbursement_amount est_cov_costs disch_alive disch_dead disch_home disch_hosp ///
	disch_nurse admin_emergency admin_urgent admin_elective admin_other ///
	source_community source_nursing source_hosp source_other male white black asian hisp ///
	age1_24 age25_44 age45_64 age65_74 age75_84 age85 drg_price est_cov_costs post_md ///
	disch_home disch_hosp disch_nurse disch_alive if cDRG==207

sutex length_of_stay drg_price reimbursement_amount est_cov_costs disch_alive disch_dead disch_home disch_hosp ///
	disch_nurse admin_emergency admin_urgent admin_elective admin_other ///
	source_community source_nursing source_hosp source_other male white black asian hisp ///
	age1_24 age25_44 age45_64 age65_74 age75_84 age85 drg_price est_cov_costs post_md ///
	disch_home disch_hosp disch_nurse disch_alive if cDRG==207, digits(3) labels

/*********Table 1: Patient Summary Statistics, DRG 207 discharged to Home or Nursing Facility***********/
sum length_of_stay drg_price reimbursement_amount est_cov_costs disch_hosp ///
	disch_nurse admin_emergency admin_urgent admin_elective admin_other ///
	source_community source_nursing source_hosp source_other male white black asian hisp ///
	age1_24 age25_44 age45_64 age65_74 age75_84 age85 drg_price est_cov_costs post_md ///
	disch_home disch_hosp disch_nurse disch_alive if cDRG==207 ///
	& (disch_home==1|disch_othnf==1|disch_snf==1) & drg_price>0 & fyear>2002

sutex length_of_stay drg_price reimbursement_amount est_cov_costs disch_hosp ///
	disch_nurse admin_emergency admin_urgent admin_elective admin_other ///
	source_community source_nursing source_hosp source_other male white black asian hisp ///
	age1_24 age25_44 age45_64 age65_74 age75_84 age85 drg_price est_cov_costs post_md ///
	disch_home disch_hosp disch_nurse disch_alive ///
	if cDRG==207 & (disch_home==1|disch_othnf==1|disch_snf==1) & drg_price>0 ///
	& fyear>2002, digits(3) labels

}
/********************************************************************************
LTCH Summary Statistics
************************************************************************/
if `hosp_sum_stat'==1 {
use data/Provider_of_Service_Files/POS_thin_ALL.dta,clear
keep clmcount prov_id year
sort prov_id year
save data/Provider_of_Service_Files/POS_clmcount.dta,replace

use data/Provider_of_Service_Files/POS_LTAC_ALL.dta,clear
sort prov_id year
/*
gen kindred =  owner=="KINDRED"
gen select  =  owner=="SELECT"*/
gen aha_hwh = colocating~=""
gen prov_medschlaffl = prov_medschl==1|prov_medschl==2|prov_medschl==3
replace prov_medschlaffl = . if prov_medschl==.

lab var kindred "Kindred"
lab var select "Select"
lab var aha_hwh "Hospital withing hospital"
lab var prov_fp "For-profit"
lab var prov_nfp "Not for-profit"
lab var prov_govt "Government owned"
lab var prov_beds "Bed count"
lab var prov_medschlaffl "Affiliated with medical school"

/****Table 2: Facility Summary Statistics*****/
sum kindred select aha_hwh prov_fp prov_nfp prov_govt prov_beds prov_medschlaffl if claim_cnt>0 & claim_cnt~=. 
sutex kindred select aha_hwh prov_fp prov_nfp prov_govt prov_beds prov_medschlaffl ///
	if claim_cnt>0 & claim_cnt~=. , digits(3) labels 

/**Weighting by bed**/
sum kindred select aha_hwh prov_fp prov_nfp prov_govt prov_medschlaffl if claim_cnt>0 & claim_cnt~=. [fw=prov_beds]
sutex kindred select aha_hwh prov_fp prov_nfp prov_govt prov_medschlaffl ///
	if claim_cnt>0 & claim_cnt~=. [fw=prov_beds], digits(3) labels 




}

log close
