/******************************************************************************
pooled_DRG_sumstats.do

This computes summary statistics for cDRG207.
*******************************************************************************/

clear all
set more off
cap log close
set mem 12000m

cd /net/storage-01/econ/research/jr139/LTCH/

log using work/summary_stats/pooled_DRG_sumstats.txt, text replace

use data/MEDPAR_POS_ALL.dta


/****************************************************************************
Plot and table describing how many observations and how many of total 
	observations we are capturing 
	***************************************************************************/

	
gen in_sample = (cDRG>0)
sort fyear
by fyear: gen first_year = _n==1
by fyear: egen portion = mean(in_sample)
by fyear: egen tot_is = total(in_sample)
by fyear: egen tot = count(in_sample)

gr twoway (line portion fyear if first_year==1), ///
		   yscale(range(.1 .7)) ytick(.1 .2 .3 .4 .5 .6 .7) ///
		   ylabel(.1 .2 .3 .4 .5 .6 .7) xscale(range(2002 2013)) 
		   
gr twoway (line tot_is fyear if first_year==1) ///
		  (line tot fyear if first_year==1), ///
		  

tabstat in_sample,by(fyear)

tab fyear


/***********************************************************************
	Types of DRG
	***************************************************************************/

/***DRG Types Defined***/
gen fphwh = (prov_fp==1)*(aha_hwh==1)
gen fpnhwh = (prov_fp==1)*(aha_hwh==0)
gen nphwh = (prov_fp==0)*(aha_hwh==1)
gen npnhwh = (prov_fp==0)*(aha_hwh==0)
tabstat fphwh,by(cDRG) stat(mean sd)
tabstat fpnhwh,by(cDRG) stat(mean sd)
tabstat nphwh,by(cDRG) stat(mean sd)
tabstat npnhwh,by(cDRG) stat(mean sd)
gen types = .
replace types = 1 if fphwh==1
replace types = 2 if fpnhwh==1
replace types = 3 if nphwh==1
replace types = 4 if npnhwh==1

tab types cDRG,row


drop if cDRG==0

/**********************************************************************
	Discharge destination, by DRG
	************************************************************************/
	gen disch_hosp = disch_stch+disch_othhosp
	gen disch_nf = disch_snf+disch_othnf
	tabstat disch_alive,by(cDRG) stat(mean sum n)
	tabstat disch_home,by(cDRG) stat(mean sum n)
	tabstat disch_hosp,by(cDRG) stat(mean sum n)
	tabstat disch_nf,by(cDRG) stat(mean sum n)

/*****KEEPING ONLY DISCHARGES TO HOME CARE OR NURSING FACILITIES******/
keep if disch_home==1 | disch_nf==1

/**********************************************************************
	Length of stay, by DRG
	*************************************************************************/
tabstat length_of_stay,by(cDRG) stat(mean sd p10 p25 p50 p75 p90)	




/*********************************************************************
	payment and costs
	*************************************************************************/

/**Opening up daily payment estimates**/	
use data/daily_payoffs_stackedDRG_long.dta,clear

gen fphwh = (prov_fp==1)*(aha_hwh==1)
gen fpnhwh = (prov_fp==1)*(aha_hwh==0)
gen nphwh = (prov_fp==0)*(aha_hwh==1)
gen npnhwh = (prov_fp==0)*(aha_hwh==0)
gen types = .
replace types = 1 if fphwh==1
replace types = 2 if fpnhwh==1
replace types = 3 if nphwh==1
replace types = 4 if npnhwh==1

sum p_t if day==2,d

cap drop chain
gen chain = 0
replace chain = 1 if select==1
replace chain = 2 if kindred==1
/**Daily payments**/
tabstat p_t if day==2,by(cDRG) stat(mean median p25 p75)
tabstat p_t if day==2,by(prov_fp) stat(mean median p25 p75)
tabstat p_t if day==2,by(aha_hwh) stat(mean median p25 p75)
tabstat p_t if day==2,by(types) stat(mean median p25 p75)
tabstat p_t if day==2,by(chain) stat(mean median p25 p75)

/**Full payments**/
tabstat fullpayment if day==2,by(cDRG) stat(mean median p25 p75)
tabstat fullpayment  if day==2,by(prov_fp) stat(mean median p25 p75)
tabstat fullpayment  if day==2,by(aha_hwh) stat(mean median p25 p75)
tabstat fullpayment  if day==2,by(types) stat(mean median p25 p75)
tabstat fullpayment  if day==2,by(chain) stat(mean median p25 p75)
/**Magic day payment**/
tabstat p_t if magic_day==1,by(cDRG) stat(mean median p25 p75)
tabstat p_t if magic_day==1,by(prov_fp) stat(mean median p25 p75)
tabstat p_t if magic_day==1,by(aha_hwh) stat(mean median p25 p75)
tabstat p_t if magic_day==1,by(types) stat(mean median p25 p75)
tabstat p_t if magic_day==1,by(chain) stat(mean median p25 p75)


/**Opening up daily cost estimates**/
use data/daily_costs.dta,clear

cap drop chain
gen chain = 0
replace chain = 1 if select==1
replace chain = 2 if kindred==1

gen fphwh = (prov_fp==1)*(aha_hwh==1)
gen fpnhwh = (prov_fp==1)*(aha_hwh==0)
gen nphwh = (prov_fp==0)*(aha_hwh==1)
gen npnhwh = (prov_fp==0)*(aha_hwh==0)
gen types = .
replace types = 1 if fphwh==1
replace types = 2 if fpnhwh==1
replace types = 3 if nphwh==1
replace types = 4 if npnhwh==1
sum c_t if day==2,d

tabstat c_t if day==2,by(cDRG) stat(mean median p25 p75)
tabstat c_t if day==2,by(prov_fp) stat(mean median p25 p75)
tabstat c_t if day==2,by(aha_hwh) stat(mean median p25 p75)
tabstat c_t if day==2,by(types) stat(mean median p25 p75)
tabstat c_t if day==2,by(chain) stat(mean median p25 p75)

log close
